import { trigger, state, transition, style, animate, AUTO_STYLE, group, query, stagger, animateChild } from '@angular/animations';
import { isBoolean } from '@tstdl/base/utils';
import { filterUndefinedObjectProperties, mapObjectValues } from '@tstdl/base/utils/object';

const dropdownAnimation = trigger('dropdown', [
    state('false', style({
        height: 0,
        opacity: 0
    })),
    state('true', style({
        height: '*',
        opacity: 1
    })),
    transition('false <=> true', animate('300ms cubic-bezier(.35, 0, .25, 1)'))
]);

function enterAnimation({ timing = '350ms ease', height, opacity, scale } = {}) {
    const voidStyle = filterUndefinedObjectProperties({
        height: (height != false) ? '0px' : undefined,
        opacity: (opacity != false) ? 0 : undefined,
        scale: (scale != false) ? (isBoolean(scale) ? 0 : scale) : undefined,
        visibility: 'hidden'
    });
    const targetStyle = mapObjectValues(voidStyle, () => AUTO_STYLE);
    return trigger('enter', [
        state('void', style(voidStyle)),
        state('*', style(targetStyle)),
        transition('* <=> *', animate(timing))
    ]);
}

function fadeInOutAnimation(duration, targetOpacity = 1) {
    return trigger('fadeInOut', [
        state('*', style({ opacity: targetOpacity })),
        state('void', style({ opacity: 0 })),
        transition('* <=> *', animate(duration))
    ]);
}

function fadeInRightAnimation(duration) {
    return trigger('fadeInRight', [
        transition(':enter', [
            style({
                transform: 'translateX(-20px)',
                opacity: 0
            }),
            animate(`${duration}ms cubic-bezier(0.35, 0, 0.25, 1)`, style({
                transform: 'translateX(0)',
                opacity: 1
            }))
        ])
    ]);
}
const fadeInRight400ms = fadeInRightAnimation(400);

function fadeInUpAnimation(duration) {
    return trigger('fadeInUp', [
        transition(':enter', [
            style({
                transform: 'translateY(20px)',
                opacity: 0
            }),
            animate(`${duration}ms cubic-bezier(0.35, 0, 0.25, 1)`, style({
                transform: 'translateY(0)',
                opacity: 1
            }))
        ])
    ]);
}
const fadeInUp400ms = fadeInUpAnimation(400);

const popoverAnimation = trigger('transformPopover', [
    transition(':enter', [
        style({
            opacity: 0,
            transform: 'scale(0.6)'
        }),
        group([
            animate('100ms linear', style({
                opacity: 1
            })),
            animate('150ms cubic-bezier(0, 0, 0.2, 1)', style({
                transform: 'scale(1)'
            }))
        ])
    ]),
    transition(':leave', [
        style({
            opacity: 1
        }),
        animate('100ms linear', style({
            opacity: 0
        }))
    ])
]);

function scaleFadeInAnimation(duration) {
    return trigger('scaleFadeIn', [
        transition(':enter', [
            style({
                transform: 'scale(0.8)',
                opacity: 0
            }),
            animate(`${duration}ms cubic-bezier(0.35, 0, 0.25, 1)`, style({
                transform: 'scale(1)',
                opacity: 1
            }))
        ])
    ]);
}
const scaleFadeIn400ms = scaleFadeInAnimation(400);

const scaleInOutAnimation = trigger('scaleInOut', [
    transition(':enter', [
        style({
            transform: 'scale(0)',
            opacity: 0
        }),
        animate('0.2s cubic-bezier(0.35, 0, 0.25, 1)', style({
            transform: 'scale(1)',
            opacity: 1
        }))
    ]),
    transition(':leave', [
        style({
            transform: 'scale(1)',
            opacity: 1
        }),
        animate('0.2s cubic-bezier(0.35, 0, 0.25, 1)', style({
            transform: 'scale(0)',
            opacity: 0
        }))
    ])
]);

function scaleInAnimation(duration) {
    return trigger('scaleIn', [
        transition(':enter', [
            style({
                transform: 'scale(0)'
            }),
            animate(`${duration}ms cubic-bezier(0.35, 0, 0.25, 1)`, style({
                transform: 'scale(1)'
            }))
        ])
    ]);
}
const scaleIn400ms = scaleInAnimation(400);

function staggerAnimation(timing) {
    return trigger('stagger', [
        transition('* => *', [
            query(':enter', stagger(timing, animateChild()), { optional: true })
        ])
    ]);
}

/**
 * Generated bundle index. Do not edit.
 */

export { dropdownAnimation, enterAnimation, fadeInOutAnimation, fadeInRight400ms, fadeInRightAnimation, fadeInUp400ms, fadeInUpAnimation, popoverAnimation, scaleFadeIn400ms, scaleFadeInAnimation, scaleIn400ms, scaleInAnimation, scaleInOutAnimation, staggerAnimation };
//# sourceMappingURL=tstdl-angular-animations.mjs.map
