import { NgIf, NgTemplateOutlet, NgSwitch, NgSwitchCase, NgClass, NgFor } from '@angular/common';
import * as i0 from '@angular/core';
import { InjectionToken, TemplateRef, Inject, Optional, Directive, Input, ContentChild, ContentChildren, ChangeDetectionStrategy, Component, NgModule } from '@angular/core';
import { DynamicTextPipe, LocalizeEnumPipe, NumberLocalePipe, DateTimeLocalePipe, NumericDateToDateTimePipe, NumericTimeToDateTimePipe } from '@tstdl/angular';
import { isString, isNullOrUndefined, isNotNullOrUndefined, isNumber, isDate, isBoolean, isDefined } from '@tstdl/base/utils';
import { createArray } from '@tstdl/base/utils/array';
import { switchMap, merge, startWith } from 'rxjs';
import { DateTime, Duration } from 'luxon';

const GRID_CONTENT = new InjectionToken('GridContent');

class GridLabelDirective {
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: GridLabelDirective, deps: [{ token: TemplateRef, optional: true }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.9", type: GridLabelDirective, isStandalone: true, selector: "[gridLabel]", exportAs: ["gridLabel"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: GridLabelDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[gridLabel]',
                    exportAs: 'gridLabel',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.TemplateRef, decorators: [{
                    type: Inject,
                    args: [TemplateRef]
                }, {
                    type: Optional
                }] }] });

class GridValueDirective {
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: GridValueDirective, deps: [{ token: TemplateRef, optional: true }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.9", type: GridValueDirective, isStandalone: true, selector: "[gridValue]", exportAs: ["gridValue"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: GridValueDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[gridValue]',
                    exportAs: 'gridValue',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.TemplateRef, decorators: [{
                    type: Inject,
                    args: [TemplateRef]
                }, {
                    type: Optional
                }] }] });

class GridItemDirective {
    set gridItem(label) {
        this.label = (isString(label) && (label.length == 0)) ? null : label;
    }
    get labelTemplateRef() {
        return this.labelRef?.templateRef;
    }
    get valueTemplateRef() {
        return this.templateRef ?? this.valueRef?.templateRef;
    }
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: GridItemDirective, deps: [{ token: TemplateRef, optional: true }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.9", type: GridItemDirective, isStandalone: true, selector: "[gridItem]", inputs: { label: "label", value: "value", valueType: "valueType", enum: "enum", nullValue: "nullValue", suffix: "suffix", colSpan: "colSpan", rowSpan: "rowSpan", booleanTrueText: "booleanTrueText", booleanFalseText: "booleanFalseText", noValueText: "noValueText", gridItem: "gridItem" }, providers: [
            { provide: GRID_CONTENT, useExisting: GridItemDirective }
        ], queries: [{ propertyName: "labelRef", first: true, predicate: GridLabelDirective, descendants: true }, { propertyName: "valueRef", first: true, predicate: GridValueDirective, descendants: true }], exportAs: ["gridItem"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: GridItemDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[gridItem]',
                    exportAs: 'gridItem',
                    standalone: true,
                    providers: [
                        { provide: GRID_CONTENT, useExisting: GridItemDirective }
                    ]
                }]
        }], ctorParameters: () => [{ type: i0.TemplateRef, decorators: [{
                    type: Inject,
                    args: [TemplateRef]
                }, {
                    type: Optional
                }] }], propDecorators: { label: [{
                type: Input
            }], value: [{
                type: Input
            }], valueType: [{
                type: Input
            }], enum: [{
                type: Input
            }], nullValue: [{
                type: Input
            }], suffix: [{
                type: Input
            }], colSpan: [{
                type: Input
            }], rowSpan: [{
                type: Input
            }], booleanTrueText: [{
                type: Input
            }], booleanFalseText: [{
                type: Input
            }], noValueText: [{
                type: Input
            }], labelRef: [{
                type: ContentChild,
                args: [GridLabelDirective]
            }], valueRef: [{
                type: ContentChild,
                args: [GridValueDirective]
            }], gridItem: [{
                type: Input
            }] } });

class GridColumnDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: GridColumnDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.9", type: GridColumnDirective, isStandalone: true, selector: "[gridColumn]", providers: [
            { provide: GRID_CONTENT, useExisting: GridColumnDirective }
        ], queries: [{ propertyName: "items", predicate: GridItemDirective }], exportAs: ["gridColumn"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: GridColumnDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[gridColumn]',
                    exportAs: 'gridColumn',
                    standalone: true,
                    providers: [
                        { provide: GRID_CONTENT, useExisting: GridColumnDirective }
                    ]
                }]
        }], propDecorators: { items: [{
                type: ContentChildren,
                args: [GridItemDirective]
            }] } });

class GridHeaderItemDirective {
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: GridHeaderItemDirective, deps: [{ token: TemplateRef, optional: true }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.9", type: GridHeaderItemDirective, isStandalone: true, selector: "[gridHeaderItem]", inputs: { label: "label", enum: "enum" }, exportAs: ["gridHeaderItem"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: GridHeaderItemDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[gridHeaderItem]',
                    exportAs: 'gridHeaderItem',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.TemplateRef, decorators: [{
                    type: Inject,
                    args: [TemplateRef]
                }, {
                    type: Optional
                }] }], propDecorators: { label: [{
                type: Input
            }], enum: [{
                type: Input
            }] } });

class GridRowDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: GridRowDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.9", type: GridRowDirective, isStandalone: true, selector: "[gridRow]", providers: [
            { provide: GRID_CONTENT, useExisting: GridRowDirective }
        ], queries: [{ propertyName: "items", predicate: GridItemDirective }], exportAs: ["gridRow"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: GridRowDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[gridRow]',
                    exportAs: 'gridRow',
                    standalone: true,
                    providers: [
                        { provide: GRID_CONTENT, useExisting: GridRowDirective }
                    ]
                }]
        }], propDecorators: { items: [{
                type: ContentChildren,
                args: [GridItemDirective]
            }] } });

class DataGridOptions {
}
function provideDataGridOptions(options) {
    return { provide: DataGridOptions, useValue: options };
}

class GridLabelComponent {
    constructor(_changeDetector) {
        this.colon = false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: GridLabelComponent, deps: [{ token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.9", type: GridLabelComponent, isStandalone: true, selector: "tsl-grid-label", inputs: { label: "label", enum: "enum", templateRef: "templateRef", colon: "colon" }, host: { classAttribute: "leading-4 font-semibold" }, ngImport: i0, template: "<ng-container *ngIf=\"templateRef\" [ngTemplateOutlet]=\"templateRef\"></ng-container>\n\n<ng-container *ngIf=\"label != undefined; else enumLabel\">\n  {{ label | dynamicText }} {{ colon ? ':' : '' }}\n</ng-container>\n\n<ng-template #enumLabel>\n  <ng-container *ngIf=\"enum\">\n    {{ enum | localizeEnum }} {{ colon ? ':' : '' }}\n  </ng-container>\n</ng-template>\n", styles: [""], dependencies: [{ kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "pipe", type: DynamicTextPipe, name: "dynamicText" }, { kind: "pipe", type: LocalizeEnumPipe, name: "localizeEnum" }], changeDetection: i0.ChangeDetectionStrategy.Default }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: GridLabelComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tsl-grid-label', imports: [NgIf, NgTemplateOutlet, DynamicTextPipe, LocalizeEnumPipe], changeDetection: ChangeDetectionStrategy.Default, host: {
                        class: 'leading-4 font-semibold'
                    }, template: "<ng-container *ngIf=\"templateRef\" [ngTemplateOutlet]=\"templateRef\"></ng-container>\n\n<ng-container *ngIf=\"label != undefined; else enumLabel\">\n  {{ label | dynamicText }} {{ colon ? ':' : '' }}\n</ng-container>\n\n<ng-template #enumLabel>\n  <ng-container *ngIf=\"enum\">\n    {{ enum | localizeEnum }} {{ colon ? ':' : '' }}\n  </ng-container>\n</ng-template>\n" }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }], propDecorators: { label: [{
                type: Input
            }], enum: [{
                type: Input
            }], templateRef: [{
                type: Input
            }], colon: [{
                type: Input
            }] } });

const dateShort = {
    year: 'numeric',
    month: '2-digit',
    day: '2-digit'
};
const timeShort = {
    hour: '2-digit',
    minute: '2-digit'
};
class GridValueComponent {
    constructor() {
        this.dateShort = dateShort;
        this.timeShort = timeShort;
    }
    get percentFormat() {
        return { style: 'percent', minimumFractionDigits: 2, ...this.numberFormat };
    }
    get percentPointFormat() {
        return { style: 'percent', minimumFractionDigits: 2, ...this.numberFormat };
    }
    get currencyFormat() {
        return { style: 'currency', currency: 'EUR', ...this.numberFormat };
    }
    ngOnChanges() {
        if (isNullOrUndefined(this.item)) {
            this.actualValue = null;
            this.actualValueType = null;
        }
        else if (isNullOrUndefined(this.item.value)) {
            this.actualValue = this.item.nullValue;
            this.actualValueType = this.getActualValueType(this.item.nullValue);
        }
        else {
            this.actualValue = this.item.value;
            this.actualValueType = this.item.valueType ?? this.getActualValueType(this.item.value);
        }
    }
    getActualValueType(value) {
        if (isNullOrUndefined(value) || isNullOrUndefined(this.item)) {
            return null;
        }
        if (isNotNullOrUndefined(this.item.enum)) {
            return 'enum';
        }
        if (isNumber(value)) {
            return 'number';
        }
        if (isString(value)) {
            return 'text';
        }
        if ((value instanceof DateTime) || isDate(value)) {
            return 'date';
        }
        if (value instanceof Duration) {
            return 'time';
        }
        if (isBoolean(value)) {
            return 'boolean';
        }
        return null;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: GridValueComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.9", type: GridValueComponent, isStandalone: true, selector: "tsl-grid-value", inputs: { item: "item", numberFormat: "numberFormat", dateFormat: "dateFormat", timeFormat: "timeFormat", booleanTrueText: "booleanTrueText", booleanFalseText: "booleanFalseText", noValueText: "noValueText" }, host: { classAttribute: "leading-4" }, usesOnChanges: true, ngImport: i0, template: "<ng-container *ngIf=\"item\">\n  <ng-container *ngIf=\"item.valueTemplateRef; else valueTemplate\" [ngTemplateOutlet]=\"item.valueTemplateRef\"></ng-container>\n\n  <ng-template #valueTemplate>\n    <ng-container *ngIf=\"actualValueType != undefined; else noValue\">\n      <ng-container *ngIf=\"actualValue != undefined; else noValue\" [ngSwitch]=\"actualValueType\">\n        <ng-container *ngSwitchCase=\"'plain'\">{{ actualValue }}</ng-container>\n        <ng-container *ngSwitchCase=\"'text'\">{{ actualValue | dynamicText }}</ng-container>\n        <ng-container *ngSwitchCase=\"'number'\">{{ actualValue | numberLocale:numberFormat }}</ng-container>\n        <ng-container *ngSwitchCase=\"'boolean'\">{{ (actualValue ?? false) ? ((booleanTrueText ?? 'Yes') | dynamicText) : ((booleanFalseText ?? 'No') | dynamicText) }}</ng-container>\n        <ng-container *ngSwitchCase=\"'percent'\">{{ actualValue | numberLocale:percentFormat }}</ng-container>\n        <ng-container *ngSwitchCase=\"'percent-point'\">{{ (actualValue / 100) | numberLocale:percentPointFormat }}</ng-container>\n        <ng-container *ngSwitchCase=\"'currency'\">{{ actualValue | numberLocale:currencyFormat }}</ng-container>\n        <ng-container *ngSwitchCase=\"'date'\">{{ actualValue | dateTimeLocale:(dateFormat ?? dateShort) }}</ng-container>\n        <ng-container *ngSwitchCase=\"'numeric-date'\">{{ actualValue | numericDateToDateTime | dateTimeLocale:(dateFormat ?? dateShort) }}</ng-container>\n        <ng-container *ngSwitchCase=\"'time'\">{{ actualValue | dateTimeLocale:(timeFormat ?? timeShort) }}</ng-container>\n        <ng-container *ngSwitchCase=\"'numeric-time'\">{{ actualValue | numericTimeToDateTime | dateTimeLocale:(timeFormat ?? timeShort) }}</ng-container>\n        <ng-container *ngSwitchCase=\"'enum'\">\n          <ng-container *ngIf=\"item.enum; else missingEnum\">{{ actualValue | localizeEnum:item.enum }}</ng-container>\n          <ng-template #missingEnum>MISSING_ENUM</ng-template>\n        </ng-container>\n      </ng-container>\n\n      <ng-container *ngIf=\"item.suffix\"> {{ item.suffix }}</ng-container>\n    </ng-container>\n  </ng-template>\n  <ng-template #noValue>{{ (noValueText ?? 'N/A') | dynamicText }}</ng-template>\n</ng-container>\n", styles: [""], dependencies: [{ kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }, { kind: "pipe", type: DynamicTextPipe, name: "dynamicText" }, { kind: "pipe", type: NumberLocalePipe, name: "numberLocale" }, { kind: "pipe", type: DateTimeLocalePipe, name: "dateTimeLocale" }, { kind: "pipe", type: NumericDateToDateTimePipe, name: "numericDateToDateTime" }, { kind: "pipe", type: LocalizeEnumPipe, name: "localizeEnum" }, { kind: "pipe", type: NumericTimeToDateTimePipe, name: "numericTimeToDateTime" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: GridValueComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tsl-grid-value', imports: [NgIf, NgTemplateOutlet, NgSwitch, NgSwitchCase, DynamicTextPipe, NumberLocalePipe, DateTimeLocalePipe, NumericDateToDateTimePipe, LocalizeEnumPipe, NumericTimeToDateTimePipe], changeDetection: ChangeDetectionStrategy.OnPush, host: {
                        class: 'leading-4'
                    }, template: "<ng-container *ngIf=\"item\">\n  <ng-container *ngIf=\"item.valueTemplateRef; else valueTemplate\" [ngTemplateOutlet]=\"item.valueTemplateRef\"></ng-container>\n\n  <ng-template #valueTemplate>\n    <ng-container *ngIf=\"actualValueType != undefined; else noValue\">\n      <ng-container *ngIf=\"actualValue != undefined; else noValue\" [ngSwitch]=\"actualValueType\">\n        <ng-container *ngSwitchCase=\"'plain'\">{{ actualValue }}</ng-container>\n        <ng-container *ngSwitchCase=\"'text'\">{{ actualValue | dynamicText }}</ng-container>\n        <ng-container *ngSwitchCase=\"'number'\">{{ actualValue | numberLocale:numberFormat }}</ng-container>\n        <ng-container *ngSwitchCase=\"'boolean'\">{{ (actualValue ?? false) ? ((booleanTrueText ?? 'Yes') | dynamicText) : ((booleanFalseText ?? 'No') | dynamicText) }}</ng-container>\n        <ng-container *ngSwitchCase=\"'percent'\">{{ actualValue | numberLocale:percentFormat }}</ng-container>\n        <ng-container *ngSwitchCase=\"'percent-point'\">{{ (actualValue / 100) | numberLocale:percentPointFormat }}</ng-container>\n        <ng-container *ngSwitchCase=\"'currency'\">{{ actualValue | numberLocale:currencyFormat }}</ng-container>\n        <ng-container *ngSwitchCase=\"'date'\">{{ actualValue | dateTimeLocale:(dateFormat ?? dateShort) }}</ng-container>\n        <ng-container *ngSwitchCase=\"'numeric-date'\">{{ actualValue | numericDateToDateTime | dateTimeLocale:(dateFormat ?? dateShort) }}</ng-container>\n        <ng-container *ngSwitchCase=\"'time'\">{{ actualValue | dateTimeLocale:(timeFormat ?? timeShort) }}</ng-container>\n        <ng-container *ngSwitchCase=\"'numeric-time'\">{{ actualValue | numericTimeToDateTime | dateTimeLocale:(timeFormat ?? timeShort) }}</ng-container>\n        <ng-container *ngSwitchCase=\"'enum'\">\n          <ng-container *ngIf=\"item.enum; else missingEnum\">{{ actualValue | localizeEnum:item.enum }}</ng-container>\n          <ng-template #missingEnum>MISSING_ENUM</ng-template>\n        </ng-container>\n      </ng-container>\n\n      <ng-container *ngIf=\"item.suffix\"> {{ item.suffix }}</ng-container>\n    </ng-container>\n  </ng-template>\n  <ng-template #noValue>{{ (noValueText ?? 'N/A') | dynamicText }}</ng-template>\n</ng-container>\n" }]
        }], propDecorators: { item: [{
                type: Input
            }], numberFormat: [{
                type: Input
            }], dateFormat: [{
                type: Input
            }], timeFormat: [{
                type: Input
            }], booleanTrueText: [{
                type: Input
            }], booleanFalseText: [{
                type: Input
            }], noValueText: [{
                type: Input
            }] } });

const columnClasses = {
    1: 'grid-cols-1',
    2: 'grid-cols-2',
    3: 'grid-cols-3',
    4: 'grid-cols-4',
    5: 'grid-cols-5',
    6: 'grid-cols-6',
    7: 'grid-cols-7',
    8: 'grid-cols-8',
    9: 'grid-cols-9',
    10: 'grid-cols-10'
};
const colSpanClasses = {
    1: 'col-span-1',
    2: 'col-span-2',
    3: 'col-span-3',
    4: 'col-span-4',
    5: 'col-span-5',
    6: 'col-span-6',
    7: 'col-span-7',
    8: 'col-span-8',
    9: 'col-span-9',
    10: 'col-span-10'
};
const rowSpanClasses = {
    1: 'row-span-1',
    2: 'row-span-2',
    3: 'row-span-3',
    4: 'row-span-4',
    5: 'row-span-5',
    6: 'row-span-6',
    7: 'row-span-7',
    8: 'row-span-8',
    9: 'row-span-9',
    10: 'row-span-10'
};
class DataGridComponent {
    get empty() {
        return this.matrix.length == 0;
    }
    constructor(changeDetector, options) {
        this.columnClasses = columnClasses;
        this.colSpanClasses = colSpanClasses;
        this.rowSpanClasses = rowSpanClasses;
        this.changeDetector = changeDetector;
        this.itemColumns = options?.itemColumns ?? 4;
        this.booleanTrueText = options?.booleanTrueText;
        this.booleanFalseText = options?.booleanFalseText;
        this.noValueText = options?.noValueText;
        this.contentInit = false;
    }
    ngAfterContentInit() {
        this.contentInit = true;
        const columnItemsChange$ = this.columnRefs.changes.pipe(switchMap(() => merge(this.columnRefs.map((column) => column.items.changes))));
        const rowItemsChange$ = this.rowRefs.changes.pipe(switchMap(() => merge(this.rowRefs.map((row) => row.items.changes))));
        merge(this.headerItemRefs.changes, this.itemRefs.changes, this.columnRefs.changes, this.rowRefs.changes, columnItemsChange$, rowItemsChange$)
            .pipe(startWith(undefined))
            .subscribe(() => this.update());
    }
    ngOnChanges() {
        this.update();
    }
    isOddItemsRow(index) {
        return Math.floor(index / this.itemColumns) % 2 == 1;
    }
    update() {
        if (!this.contentInit) {
            return;
        }
        this.updateMatrix();
        this.updateActualDisplayType();
        this.changeDetector.markForCheck();
    }
    updateMatrix() {
        if (this.rowRefs.length > 0) {
            this.columns = this.rowRefs.map((row) => row.items.length).reduce((max, length) => Math.max(max, length), 0);
            this.matrix = this.rowRefs.map((row) => createArray(this.columns, (column) => row.items.get(column)));
        }
        else if (this.columnRefs.length > 0) {
            this.columns = this.columnRefs.length;
            const rows = this.columnRefs.map((column) => column.items.length).reduce((max, length) => Math.max(max, length), 0);
            this.matrix = createArray(rows, (row) => createArray(this.columns, (column) => this.columnRefs.get(column)?.items.get(row)));
        }
        else if (this.itemRefs.length > 0) {
            this.columns = this.itemColumns;
            const rows = Math.ceil(this.itemRefs.length / this.itemColumns);
            this.matrix = createArray(rows, (row) => createArray(this.itemColumns, (column) => this.itemRefs.get((row * this.itemColumns) + column)));
        }
        else {
            this.matrix = [];
            this.columns = this.headerItemRefs.length;
        }
    }
    updateActualDisplayType() {
        if (isDefined(this.displayType)) {
            this.actualDisplayType = this.displayType;
        }
        else if (this.rowRefs.length > 0) {
            this.actualDisplayType = 'table';
        }
        else if (this.columnRefs.length > 0) {
            this.actualDisplayType = 'columns';
        }
        else {
            this.actualDisplayType = 'items';
        }
    }
    trackBy(_index, _item) {
        return true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: DataGridComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: DataGridOptions, optional: true }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.9", type: DataGridComponent, isStandalone: true, selector: "tsl-data-grid", inputs: { heading: "heading", displayType: "displayType", itemColumns: "itemColumns", booleanTrueText: "booleanTrueText", booleanFalseText: "booleanFalseText", noValueText: "noValueText" }, host: { classAttribute: "tsl-tw block bg-white dark:bg-neutral-800 text-neutral-800 dark:text-neutral-200 border-[1.5px] border-neutral-300 dark:border-neutral-800 rounded-lg overflow-hidden break-words text-sm leading-4 break-inside-avoid isolate" }, queries: [{ propertyName: "headerItemRefs", predicate: GridHeaderItemDirective }, { propertyName: "itemRefs", predicate: GridItemDirective }, { propertyName: "columnRefs", predicate: GridColumnDirective }, { propertyName: "rowRefs", predicate: GridRowDirective }], usesOnChanges: true, ngImport: i0, template: "<div *ngIf=\"heading\" class=\"bg-neutral-300 dark:bg-neutral-800 text-neutral-900 dark:text-neutral-100 px-2 py-0.5 text-base font-bold\">{{ heading | dynamicText }}</div>\n\n<div *ngIf=\"actualDisplayType == 'items'\" class=\"grid\" [ngClass]=\"columnClasses[columns]\">\n  <ng-container [ngTemplateOutlet]=\"headerRow\"></ng-container>\n  <div *ngIf=\"empty\" class=\"text-center py-2\" [ngClass]=\"colSpanClasses[columns]\">{{ (noValueText ?? 'N/A') | dynamicText }}</div>\n\n  <ng-container *ngFor=\"let matrixRow of matrix; let rowIndex = index; let firstRow = first; let lastRow = last; let oddRow = odd; trackBy: trackBy\">\n    <ng-container *ngFor=\"let item of matrixRow; let columnIndex = index; let firstColumn = first; let lastColumn = last; trackBy: trackBy\">\n      <div class=\"flex flex-col gap-1.5 p-2\"\n           [ngClass]=\"colSpanClasses[item?.colSpan ?? 0] + ' ' + rowSpanClasses[item?.rowSpan ?? 0]\"\n           [class.border-t]=\"!firstRow\"\n           [class.bg-white]=\"!oddRow\"\n           [class.dark:bg-neutral-700]=\"!oddRow\"\n           [class.bg-neutral-100]=\"oddRow\"\n           [class.dark:bg-neutral-800]=\"oddRow\">\n        <ng-container *ngIf=\"item\">\n          <tsl-grid-label [templateRef]=\"item?.labelRef?.templateRef\" [label]=\"item?.label\" [enum]=\"item?.enum\"></tsl-grid-label>\n          <tsl-grid-value [booleanTrueText]=\"booleanTrueText\" [booleanFalseText]=\"booleanFalseText\" [noValueText]=\"noValueText\" [item]=\"item\"></tsl-grid-value>\n        </ng-container>\n      </div>\n    </ng-container>\n  </ng-container>\n</div>\n\n<div *ngIf=\"actualDisplayType == 'table'\" class=\"grid\" [ngClass]=\"columnClasses[columns]\">\n  <ng-container [ngTemplateOutlet]=\"headerRow\"></ng-container>\n  <div *ngIf=\"empty\" class=\"text-center py-2\" [ngClass]=\"colSpanClasses[columns]\">{{ (noValueText ?? 'N/A') | dynamicText }}</div>\n\n  <ng-container *ngFor=\"let matrixRow of matrix; let rowIndex = index; let firstRow = first; let lastRow = last; let oddRow = odd; trackBy: trackBy\">\n    <ng-container *ngFor=\"let item of matrixRow; let columnIndex = index; let firstColumn = first; let lastColumn = last; trackBy: trackBy\">\n      <tsl-grid-value [item]=\"item\"\n                      [booleanTrueText]=\"booleanTrueText\"\n                      [booleanFalseText]=\"booleanFalseText\"\n                      [noValueText]=\"noValueText\"\n                      class=\"px-2 py-1.5\"\n                      [class.border-t]=\"!firstRow\"\n                      [class.bg-white]=\"!oddRow\"\n                      [class.dark:bg-neutral-700]=\"!oddRow\"\n                      [class.bg-neutral-100]=\"oddRow\"\n                      [class.dark:bg-neutral-800]=\"oddRow\"></tsl-grid-value>\n    </ng-container>\n  </ng-container>\n</div>\n\n<div *ngIf=\"actualDisplayType == 'columns'\" class=\"grid\" [ngClass]=\"columnClasses[columns * 2]\">\n  <ng-container [ngTemplateOutlet]=\"headerRow\"></ng-container>\n  <div *ngIf=\"empty\" class=\"text-center py-2\" [ngClass]=\"colSpanClasses[columns]\">{{ (noValueText ?? 'N/A') | dynamicText }}</div>\n\n  <ng-container *ngFor=\"let matrixRow of matrix; let rowIndex = index; let firstRow = first; let lastRow = last; let oddRow = odd; trackBy: trackBy\">\n    <ng-container *ngFor=\"let item of matrixRow; let columnIndex = index; let firstColumn = first; let lastColumn = last; trackBy: trackBy\">\n      <tsl-grid-label [templateRef]=\"item?.labelRef?.templateRef\"\n                      [label]=\"item?.label\"\n                      [enum]=\"item?.enum\"\n                      class=\"p-2\"\n                      [class.border-t]=\"!firstRow\"\n                      [class.bg-white]=\"!oddRow\"\n                      [class.dark:bg-neutral-700]=\"!oddRow\"\n                      [class.bg-neutral-100]=\"oddRow\"\n                      [class.dark:bg-neutral-800]=\"oddRow\"></tsl-grid-label>\n\n      <tsl-grid-value [item]=\"item\"\n                      [booleanTrueText]=\"booleanTrueText\"\n                      [booleanFalseText]=\"booleanFalseText\"\n                      [noValueText]=\"noValueText\"\n                      class=\"p-2\"\n                      [class.border-t]=\"!firstRow\"\n                      [class.bg-white]=\"!oddRow\"\n                      [class.dark:bg-neutral-700]=\"!oddRow\"\n                      [class.bg-neutral-100]=\"oddRow\"\n                      [class.dark:bg-neutral-800]=\"oddRow\"></tsl-grid-value>\n    </ng-container>\n  </ng-container>\n</div>\n\n<ng-template #headerRow>\n  <tsl-grid-label *ngFor=\"let headerItem of headerItemRefs; let first = first; let last = last; trackBy: trackBy\"\n                  [templateRef]=\"headerItem?.templateRef\"\n                  [label]=\"headerItem?.label\"\n                  [enum]=\"headerItem?.enum\"\n                  class=\"px-2 pb-1.5 bg-neutral-300 dark:bg-neutral-800 text-neutral-900 dark:text-neutral-100\"\n                  [class.pt-1.5]=\"heading == undefined\"></tsl-grid-label>\n</ng-template>\n", styles: [":host{contain:content;content-visibility:auto;contain-intrinsic-size:auto 25rem}\n"], dependencies: [{ kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: NgFor, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "component", type: GridLabelComponent, selector: "tsl-grid-label", inputs: ["label", "enum", "templateRef", "colon"] }, { kind: "component", type: GridValueComponent, selector: "tsl-grid-value", inputs: ["item", "numberFormat", "dateFormat", "timeFormat", "booleanTrueText", "booleanFalseText", "noValueText"] }, { kind: "pipe", type: DynamicTextPipe, name: "dynamicText" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: DataGridComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tsl-data-grid', imports: [NgIf, NgClass, NgTemplateOutlet, NgFor, GridLabelComponent, GridValueComponent, DynamicTextPipe], changeDetection: ChangeDetectionStrategy.OnPush, host: {
                        class: 'tsl-tw block bg-white dark:bg-neutral-800 text-neutral-800 dark:text-neutral-200 border-[1.5px] border-neutral-300 dark:border-neutral-800 rounded-lg overflow-hidden break-words text-sm leading-4 break-inside-avoid isolate'
                    }, template: "<div *ngIf=\"heading\" class=\"bg-neutral-300 dark:bg-neutral-800 text-neutral-900 dark:text-neutral-100 px-2 py-0.5 text-base font-bold\">{{ heading | dynamicText }}</div>\n\n<div *ngIf=\"actualDisplayType == 'items'\" class=\"grid\" [ngClass]=\"columnClasses[columns]\">\n  <ng-container [ngTemplateOutlet]=\"headerRow\"></ng-container>\n  <div *ngIf=\"empty\" class=\"text-center py-2\" [ngClass]=\"colSpanClasses[columns]\">{{ (noValueText ?? 'N/A') | dynamicText }}</div>\n\n  <ng-container *ngFor=\"let matrixRow of matrix; let rowIndex = index; let firstRow = first; let lastRow = last; let oddRow = odd; trackBy: trackBy\">\n    <ng-container *ngFor=\"let item of matrixRow; let columnIndex = index; let firstColumn = first; let lastColumn = last; trackBy: trackBy\">\n      <div class=\"flex flex-col gap-1.5 p-2\"\n           [ngClass]=\"colSpanClasses[item?.colSpan ?? 0] + ' ' + rowSpanClasses[item?.rowSpan ?? 0]\"\n           [class.border-t]=\"!firstRow\"\n           [class.bg-white]=\"!oddRow\"\n           [class.dark:bg-neutral-700]=\"!oddRow\"\n           [class.bg-neutral-100]=\"oddRow\"\n           [class.dark:bg-neutral-800]=\"oddRow\">\n        <ng-container *ngIf=\"item\">\n          <tsl-grid-label [templateRef]=\"item?.labelRef?.templateRef\" [label]=\"item?.label\" [enum]=\"item?.enum\"></tsl-grid-label>\n          <tsl-grid-value [booleanTrueText]=\"booleanTrueText\" [booleanFalseText]=\"booleanFalseText\" [noValueText]=\"noValueText\" [item]=\"item\"></tsl-grid-value>\n        </ng-container>\n      </div>\n    </ng-container>\n  </ng-container>\n</div>\n\n<div *ngIf=\"actualDisplayType == 'table'\" class=\"grid\" [ngClass]=\"columnClasses[columns]\">\n  <ng-container [ngTemplateOutlet]=\"headerRow\"></ng-container>\n  <div *ngIf=\"empty\" class=\"text-center py-2\" [ngClass]=\"colSpanClasses[columns]\">{{ (noValueText ?? 'N/A') | dynamicText }}</div>\n\n  <ng-container *ngFor=\"let matrixRow of matrix; let rowIndex = index; let firstRow = first; let lastRow = last; let oddRow = odd; trackBy: trackBy\">\n    <ng-container *ngFor=\"let item of matrixRow; let columnIndex = index; let firstColumn = first; let lastColumn = last; trackBy: trackBy\">\n      <tsl-grid-value [item]=\"item\"\n                      [booleanTrueText]=\"booleanTrueText\"\n                      [booleanFalseText]=\"booleanFalseText\"\n                      [noValueText]=\"noValueText\"\n                      class=\"px-2 py-1.5\"\n                      [class.border-t]=\"!firstRow\"\n                      [class.bg-white]=\"!oddRow\"\n                      [class.dark:bg-neutral-700]=\"!oddRow\"\n                      [class.bg-neutral-100]=\"oddRow\"\n                      [class.dark:bg-neutral-800]=\"oddRow\"></tsl-grid-value>\n    </ng-container>\n  </ng-container>\n</div>\n\n<div *ngIf=\"actualDisplayType == 'columns'\" class=\"grid\" [ngClass]=\"columnClasses[columns * 2]\">\n  <ng-container [ngTemplateOutlet]=\"headerRow\"></ng-container>\n  <div *ngIf=\"empty\" class=\"text-center py-2\" [ngClass]=\"colSpanClasses[columns]\">{{ (noValueText ?? 'N/A') | dynamicText }}</div>\n\n  <ng-container *ngFor=\"let matrixRow of matrix; let rowIndex = index; let firstRow = first; let lastRow = last; let oddRow = odd; trackBy: trackBy\">\n    <ng-container *ngFor=\"let item of matrixRow; let columnIndex = index; let firstColumn = first; let lastColumn = last; trackBy: trackBy\">\n      <tsl-grid-label [templateRef]=\"item?.labelRef?.templateRef\"\n                      [label]=\"item?.label\"\n                      [enum]=\"item?.enum\"\n                      class=\"p-2\"\n                      [class.border-t]=\"!firstRow\"\n                      [class.bg-white]=\"!oddRow\"\n                      [class.dark:bg-neutral-700]=\"!oddRow\"\n                      [class.bg-neutral-100]=\"oddRow\"\n                      [class.dark:bg-neutral-800]=\"oddRow\"></tsl-grid-label>\n\n      <tsl-grid-value [item]=\"item\"\n                      [booleanTrueText]=\"booleanTrueText\"\n                      [booleanFalseText]=\"booleanFalseText\"\n                      [noValueText]=\"noValueText\"\n                      class=\"p-2\"\n                      [class.border-t]=\"!firstRow\"\n                      [class.bg-white]=\"!oddRow\"\n                      [class.dark:bg-neutral-700]=\"!oddRow\"\n                      [class.bg-neutral-100]=\"oddRow\"\n                      [class.dark:bg-neutral-800]=\"oddRow\"></tsl-grid-value>\n    </ng-container>\n  </ng-container>\n</div>\n\n<ng-template #headerRow>\n  <tsl-grid-label *ngFor=\"let headerItem of headerItemRefs; let first = first; let last = last; trackBy: trackBy\"\n                  [templateRef]=\"headerItem?.templateRef\"\n                  [label]=\"headerItem?.label\"\n                  [enum]=\"headerItem?.enum\"\n                  class=\"px-2 pb-1.5 bg-neutral-300 dark:bg-neutral-800 text-neutral-900 dark:text-neutral-100\"\n                  [class.pt-1.5]=\"heading == undefined\"></tsl-grid-label>\n</ng-template>\n", styles: [":host{contain:content;content-visibility:auto;contain-intrinsic-size:auto 25rem}\n"] }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }, { type: DataGridOptions, decorators: [{
                    type: Inject,
                    args: [DataGridOptions]
                }, {
                    type: Optional
                }] }], propDecorators: { heading: [{
                type: Input
            }], displayType: [{
                type: Input
            }], itemColumns: [{
                type: Input
            }], booleanTrueText: [{
                type: Input
            }], booleanFalseText: [{
                type: Input
            }], noValueText: [{
                type: Input
            }], headerItemRefs: [{
                type: ContentChildren,
                args: [GridHeaderItemDirective]
            }], itemRefs: [{
                type: ContentChildren,
                args: [GridItemDirective]
            }], columnRefs: [{
                type: ContentChildren,
                args: [GridColumnDirective]
            }], rowRefs: [{
                type: ContentChildren,
                args: [GridRowDirective]
            }] } });

class TstdlDataGridModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: TstdlDataGridModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: TstdlDataGridModule, imports: [DataGridComponent,
            GridColumnDirective,
            GridHeaderItemDirective,
            GridItemDirective,
            GridLabelDirective,
            GridRowDirective,
            GridValueDirective], exports: [DataGridComponent,
            GridColumnDirective,
            GridHeaderItemDirective,
            GridItemDirective,
            GridLabelDirective,
            GridRowDirective,
            GridValueDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: TstdlDataGridModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: TstdlDataGridModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        DataGridComponent,
                        GridColumnDirective,
                        GridHeaderItemDirective,
                        GridItemDirective,
                        GridLabelDirective,
                        GridRowDirective,
                        GridValueDirective
                    ],
                    exports: [
                        DataGridComponent,
                        GridColumnDirective,
                        GridHeaderItemDirective,
                        GridItemDirective,
                        GridLabelDirective,
                        GridRowDirective,
                        GridValueDirective
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { DataGridComponent, DataGridOptions, GRID_CONTENT, GridColumnDirective, GridHeaderItemDirective, GridItemDirective, GridLabelComponent, GridLabelDirective, GridRowDirective, GridValueComponent, GridValueDirective, TstdlDataGridModule, provideDataGridOptions };
//# sourceMappingURL=tstdl-angular-data-grid.mjs.map
