import * as i0 from '@angular/core';
import { inject, ElementRef, ChangeDetectorRef, Injector, isSignal, effect, Input, ChangeDetectionStrategy, Component } from '@angular/core';
import { signal } from '@preact/signals';
import { isFunction, isUndefined } from '@tstdl/base/utils';
import { memoizeSingle } from '@tstdl/base/utils/function';
import { hasOwnProperty, objectEntries, fromEntries } from '@tstdl/base/utils/object';
import { render, createElement } from 'preact';

class ReactComponent {
    constructor() {
        this.elementRef = inject(ElementRef);
        this.changeDetector = inject(ChangeDetectorRef);
        this.injector = inject(Injector);
        this.adaptSignal = memoizeSingle((source) => _adaptSignal(source, this.injector), { weak: true });
        this.wrapFunction = memoizeSingle((fn) => _wrapFunction(fn, this.changeDetector), { weak: true });
        /** adapt angular signals to preact signals (readonly) */
        this.adaptSignals = true;
        /** wrap functions in properties (1st level only) to run change detection afterwards */
        this.wrapFunctions = true;
    }
    get propertiesValue() {
        return isSignal(this.properties) ? this.properties() : this.properties;
    }
    ngOnInit() {
        this.render();
    }
    ngOnChanges(changes) {
        this.render();
        if (hasOwnProperty(changes, 'properties')) {
            this.propertiesEffectRef?.destroy();
            if (isSignal(this.properties)) {
                this.propertiesEffectRef = effect(() => {
                    this.properties();
                    this.render();
                }, { injector: this.injector });
            }
        }
    }
    ngOnDestroy() {
        this.propertiesEffectRef?.destroy();
        render(null, this.elementRef.nativeElement);
    }
    render() {
        const properties = this.prepareProperties(this.propertiesValue);
        const element = createElement(this.component, properties);
        render(element, this.elementRef.nativeElement);
    }
    prepareProperties(properties) {
        if (!this.adaptSignals && !this.wrapFunctions) {
            return properties;
        }
        const entries = objectEntries(properties)
            .map(([key, value]) => {
            if (isSignal(value)) {
                return [key, this.adaptSignal(value)];
            }
            else if (isFunction(value)) {
                return [key, this.wrapFunction(value)];
            }
            return [key, value];
        });
        return fromEntries(entries);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: ReactComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.9", type: ReactComponent, isStandalone: true, selector: "tsl-react", inputs: { component: "component", properties: "properties", adaptSignals: "adaptSignals", wrapFunctions: "wrapFunctions" }, usesOnChanges: true, ngImport: i0, template: "", styles: [":host{display:contents}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: ReactComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tsl-react', standalone: true, changeDetection: ChangeDetectionStrategy.OnPush, template: "", styles: [":host{display:contents}\n"] }]
        }], propDecorators: { component: [{
                type: Input
            }], properties: [{
                type: Input
            }], adaptSignals: [{
                type: Input
            }], wrapFunctions: [{
                type: Input
            }] } });
function _wrapFunction(fn, changeDetector) {
    return ((...args) => {
        try {
            return fn(...args); // eslint-disable-line @typescript-eslint/no-unsafe-return
        }
        finally {
            changeDetector.markForCheck();
        }
    });
}
function _adaptSignal(source, injector) {
    const adaptedSignal = signal(source());
    const adaptedSignalWeakRef = new WeakRef(adaptedSignal);
    const subscription = effect(() => {
        const adaptedSignalRef = adaptedSignalWeakRef.deref();
        if (isUndefined(adaptedSignalRef)) {
            subscription.destroy();
            return;
        }
        adaptedSignalRef.value = source();
    }, { injector });
    return adaptedSignal;
}

/**
 * Generated bundle index. Do not edit.
 */

export { ReactComponent };
//# sourceMappingURL=tstdl-angular-react.mjs.map
