import { AUTO_STYLE, trigger, state, transition, style, animate } from '@angular/animations';
import { isDefined, isUndefined, isNullOrUndefined, getRandomString, Alphabet, noop, isDate, isNumber, isNull, isString, isNotNull, isFunction, isRegExp, timeout, isNotNullOrUndefined, assertDefinedPass, isBlob, isUint8Array, isReadableStream, toDateTime, strictEquals, isObject, isArray, numericDateToDateTime, numericTimeToTimeObject, formatError, assertStringPass, isNotFunction } from '@tstdl/base/utils';
import { filterUndefinedObjectProperties, mapObjectValues, hasOwnProperty, objectEntries, decycle } from '@tstdl/base/utils/object';
import * as i0 from '@angular/core';
import { Injectable, HostBinding, Input, ChangeDetectionStrategy, Component, Directive, inject, ElementRef, model, forwardRef, HostListener, input, output, signal, computed, booleanAttribute, DestroyRef, TemplateRef, ViewContainerRef, Renderer2, ChangeDetectorRef, afterNextRender, Injector, ErrorHandler, isSignal, resource, effect, ResourceStatus, EventEmitter, Output, Pipe, runInInjectionContext, untracked, ApplicationRef, linkedSignal, isDevMode, assertInInjectionContext, provideAppInitializer, NgModule, importProvidersFrom } from '@angular/core';
import chroma from 'chroma-js';
import { CancellationToken } from '@tstdl/base/cancellation';
import { ReplaySubject, Subject, filter, map, switchMap, defer, startWith, BehaviorSubject, EMPTY, takeUntil, fromEvent, combineLatest, shareReplay, take, merge, interval, from, of, tap, catchError, distinctUntilChanged, isObservable, firstValueFrom, race, throwError, Observable, first } from 'rxjs';
import { CommonModule, DOCUMENT as DOCUMENT$1 } from '@angular/common';
import { marked } from 'marked';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { normalizeText } from '@tstdl/base/utils/string';
import { observeResize$, observeIntersection$ } from '@tstdl/base/dom';
import { toObservable, takeUntilDestroyed, toSignal } from '@angular/core/rxjs-interop';
import { isAsyncIterable } from '@tstdl/base/utils/async-iterable-helpers';
import { __decorate } from 'tslib';
import { HttpClient, HttpHeaders, HttpErrorResponse, HttpEventType } from '@angular/common/http';
import { HttpClientResponse, HttpError, HttpErrorReason, HttpHeaders as HttpHeaders$1, HttpClientAdapter } from '@tstdl/base/http';
import { Singleton, Injector as Injector$1, isInInjectionContext, runInInjectionContext as runInInjectionContext$1 } from '@tstdl/base/injector';
import { toArray } from '@tstdl/base/utils/array';
import { DateTime, Duration } from 'luxon';
import { switchAll, configureSignals } from '@tstdl/base/signals';
import { LocalizationService, resolveDynamicText, missingLocalizationKeyText, isProxyLocalizationKey } from '@tstdl/base/text';
import * as i1 from '@angular/platform-browser';
import { serialize } from '@tstdl/base/serializer';
import { unwrapError, CustomError, tstdlErrorsLocalizationKeys } from '@tstdl/base/errors';
import { Logger } from '@tstdl/base/logger';
import { Router, ActivatedRoute } from '@angular/router';
import { configureTstdl } from '@tstdl/base';
import { DOCUMENT } from '@tstdl/base/tokens';

function getAnimateTimings(options) {
    return `${options?.duration ?? 250}ms ${options?.delay ?? 0}ms ${options?.ease ?? 'ease-in-out'}`;
}

function collapseAnimation(options = {}) {
    const animateTimings = getAnimateTimings(options);
    const hasCustomAnimation = isDefined(options.height) || isDefined(options.width) || isDefined(options.opacity) || isDefined(options.scale);
    const voidStyle = filterUndefinedObjectProperties({
        height: ((!hasCustomAnimation && options.height != false) || (options.height == true)) ? '0px' : undefined,
        width: (options.width == true) ? '0px' : undefined,
        opacity: (options.opacity == true) ? 0 : undefined,
        scale: (options.scale == true) ? 0 : undefined,
        visibility: 'hidden',
        overflow: 'hidden'
    });
    const targetStyle = mapObjectValues(voidStyle, () => AUTO_STYLE);
    return trigger(options.trigger ?? 'collapse', [
        state('true, void', style(voidStyle)),
        state('*', style(targetStyle)),
        transition(options.stateTransition ?? 'void => *, true <=> *', animate(animateTimings))
    ]);
}

function fadeInOutAnimation(options) {
    const animateTimings = getAnimateTimings(options);
    return trigger(options?.trigger ?? 'fadeInOut', [
        state('*', style({ opacity: options?.targetOpacity ?? AUTO_STYLE })),
        state('void', style({ opacity: 0 })),
        transition('* <=> *', animate(animateTimings))
    ]);
}

function widthAnimation(options) {
    const animateTimings = getAnimateTimings({ duration: 350, ease: 'ease', ...options });
    const defaultWidth = options?.defaultWidth ?? '0%';
    return trigger(options?.trigger ?? 'width', [
        state('void', style({ width: defaultWidth })),
        state('*', style({ width: '{{ width }}' }), { params: { width: defaultWidth } }),
        transition('* => *', animate(animateTimings))
    ]);
}
function heightAnimation(options) {
    const animateTimings = getAnimateTimings({ duration: 350, ease: 'ease', ...options });
    const defaultHeight = options?.defaultHeight ?? '0%';
    return trigger(options?.trigger ?? 'height', [
        state('void', style({ height: defaultHeight })),
        state('*', style({ height: '{{ height }}' }), { params: { height: defaultHeight } }),
        transition('* => *', animate(animateTimings))
    ]);
}

function slideInOutAnimation(options) {
    const animateTimings = getAnimateTimings(options);
    const offset = options?.direction == 'right' ? '100%' : '-100%';
    return trigger(options?.trigger ?? 'slideInOut', [
        state('void', style({ transform: `translateX(${offset})` })),
        state('*', style({ transform: 'translateX(0)' })),
        transition('* => *', animate(animateTimings))
    ]);
}

class LifecycleUtils {
    #destroyToken;
    /**
     * {@link CancellationToken} bound to {@link destroy$}
     */
    get destroySignal() {
        if (isUndefined(this.#destroyToken)) {
            this.#destroyToken = CancellationToken.from(this.destroySubject);
        }
        return this.#destroyToken.signal;
    }
    // eslint-disable-next-line max-statements
    constructor() {
        this.initSubject = new ReplaySubject(1);
        this.destroySubject = new ReplaySubject(1);
        this.changesSubject = new Subject();
        this.viewInitSubject = new ReplaySubject(1);
        this.contentInitSubject = new ReplaySubject(1);
        this.viewCheckedSubject = new Subject();
        this.contentCheckedSubject = new Subject();
        this.ionViewWillEnterSubject = new Subject();
        this.ionViewDidEnterSubject = new Subject();
        this.ionViewWillLeaveSubject = new Subject();
        this.ionViewDidLeaveSubject = new Subject();
        this.init$ = this.initSubject.asObservable();
        this.changes$ = this.changesSubject.asObservable();
        this.destroy$ = this.destroySubject.asObservable();
        this.viewInit$ = this.viewInitSubject.asObservable();
        this.contentInit$ = this.contentInitSubject.asObservable();
        this.viewChecked$ = this.viewCheckedSubject.asObservable();
        this.contentChecked$ = this.contentCheckedSubject.asObservable();
        this.ionViewWillEnter$ = this.ionViewWillEnterSubject.asObservable();
        this.ionViewDidEnter$ = this.ionViewDidEnterSubject.asObservable();
        this.ionViewWillLeave$ = this.ionViewWillLeaveSubject.asObservable();
        this.ionViewDidLeave$ = this.ionViewDidLeaveSubject.asObservable();
    }
    ngOnInit() {
        this.initSubject.next();
        this.initSubject.complete();
        this.destroy$.subscribe(() => {
            this.changesSubject.complete();
            this.viewCheckedSubject.complete();
            this.contentCheckedSubject.complete();
            this.ionViewWillEnterSubject.complete();
            this.ionViewDidEnterSubject.complete();
            this.ionViewWillLeaveSubject.complete();
            this.ionViewDidLeaveSubject.complete();
        });
    }
    ngOnChanges(changes) {
        this.changesSubject.next(changes);
    }
    ngOnDestroy() {
        this.destroySubject.next();
        this.destroySubject.complete();
    }
    ngAfterViewInit() {
        this.viewInitSubject.next();
        this.viewInitSubject.complete();
    }
    ngAfterContentInit() {
        this.contentInitSubject.next();
        this.contentInitSubject.complete();
    }
    ngAfterViewChecked() {
        this.viewCheckedSubject.next();
    }
    ngAfterContentChecked() {
        this.contentCheckedSubject.next();
    }
    ionViewWillEnter() {
        this.ionViewWillEnterSubject.next();
    }
    ionViewDidEnter() {
        this.ionViewDidEnterSubject.next();
    }
    ionViewWillLeave() {
        this.ionViewWillLeaveSubject.next();
    }
    ionViewDidLeave() {
        this.ionViewDidLeaveSubject.next();
    }
    observeChanges(property) {
        return this.changes$.pipe(filter((changes) => hasOwnProperty(changes, property)), map((changes) => changes[property]));
    }
    observe(property) {
        return this.init$.pipe(switchMap(() => defer(() => this.observeChanges(property).pipe(map((change) => change.currentValue), startWith(this[property])))));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: LifecycleUtils, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: LifecycleUtils }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: LifecycleUtils, decorators: [{
            type: Injectable
        }], ctorParameters: () => [] });

const progressColorScaler = chroma.scale(['#dc2626', '#ea580c', '#facc15', '#65a30d'])
    .classes([0, 0.15, 0.3, 0.45, 0.6, 0.75, 0.9, 1])
    .mode('lab');
class TstdlColoredProgressbarComponent extends LifecycleUtils {
    get backgroundColor() {
        return progressColorScaler(this.progress).alpha(0.3).hex();
    }
    get progressbarColor() {
        return progressColorScaler(this.progress).desaturate(1).hex();
    }
    get width() {
        return `${Math.min(this.progress ?? 0, 1) * 100}%`;
    }
    constructor() {
        super();
        this.progress = 0;
        this.rounded = false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: TstdlColoredProgressbarComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.9", type: TstdlColoredProgressbarComponent, isStandalone: true, selector: "tsl-colored-progressbar", inputs: { progress: "progress", rounded: "rounded" }, host: { properties: { "class.tsl-rounded-full": "this.rounded", "style.background-color": "this.backgroundColor" }, classAttribute: "tsl-tw" }, usesInheritance: true, ngImport: i0, template: "<div class=\"h-full progressbar\" [@width]=\"{ value: progress, params: { width: width } }\" [style.background-color]=\"progressbarColor\"></div>\n", styles: [":host{display:block;width:100%;height:6px;overflow:hidden;transition:background-color .5s cubic-bezier(1,0,.4,1)}\n"], animations: [
            widthAnimation({ duration: 1000, ease: 'ease' })
        ], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: TstdlColoredProgressbarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tsl-colored-progressbar', standalone: true, changeDetection: ChangeDetectionStrategy.OnPush, animations: [
                        widthAnimation({ duration: 1000, ease: 'ease' })
                    ], host: {
                        class: 'tsl-tw'
                    }, template: "<div class=\"h-full progressbar\" [@width]=\"{ value: progress, params: { width: width } }\" [style.background-color]=\"progressbarColor\"></div>\n", styles: [":host{display:block;width:100%;height:6px;overflow:hidden;transition:background-color .5s cubic-bezier(1,0,.4,1)}\n"] }]
        }], ctorParameters: () => [], propDecorators: { progress: [{
                type: Input
            }], rounded: [{
                type: HostBinding,
                args: ['class.tsl-rounded-full']
            }, {
                type: Input
            }], backgroundColor: [{
                type: HostBinding,
                args: ['style.background-color']
            }] } });

class TstdlIndeterminateProgressBarComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: TstdlIndeterminateProgressBarComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.9", type: TstdlIndeterminateProgressBarComponent, isStandalone: true, selector: "tsl-indeterminate-progress-bar", host: { classAttribute: "tsl-tw block relative h-1.5 overflow-hidden" }, ngImport: i0, template: "<div class=\"progress absolute top-0 bottom-0 w-1/2 bg-accent-700 dark:bg-accent-500\"></div>\n", styles: [".progress{animation:2.5s ease infinite indeterminate-progress-bar}@keyframes indeterminate-progress-bar{0%{left:-50%}85%{left:100%}to{left:100%}}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: TstdlIndeterminateProgressBarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tsl-indeterminate-progress-bar', imports: [CommonModule], changeDetection: ChangeDetectionStrategy.OnPush, host: {
                        class: 'tsl-tw block relative h-1.5 overflow-hidden'
                    }, template: "<div class=\"progress absolute top-0 bottom-0 w-1/2 bg-accent-700 dark:bg-accent-500\"></div>\n", styles: [".progress{animation:2.5s ease infinite indeterminate-progress-bar}@keyframes indeterminate-progress-bar{0%{left:-50%}85%{left:100%}to{left:100%}}\n"] }]
        }] });

class TstdlMarkdownComponent {
    get markdownHtml() {
        return marked(this.markdown ?? '');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: TstdlMarkdownComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.9", type: TstdlMarkdownComponent, isStandalone: true, selector: "tsl-markdown, [tslMarkdown]", inputs: { markdown: "markdown" }, host: { properties: { "innerHTML": "this.markdownHtml" } }, ngImport: i0, template: "", styles: [""], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: TstdlMarkdownComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tsl-markdown, [tslMarkdown]', imports: [], changeDetection: ChangeDetectionStrategy.OnPush, template: "" }]
        }], propDecorators: { markdown: [{
                type: Input
            }], markdownHtml: [{
                type: HostBinding,
                args: ['innerHTML']
            }] } });

class TstdlSkeletonComponent {
    get light() {
        return this.dark === false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: TstdlSkeletonComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.9", type: TstdlSkeletonComponent, isStandalone: true, selector: "tsl-skeleton", inputs: { dark: "dark", width: "width", height: "height", borderRadius: "borderRadius", pulseSize: "pulseSize", pulseScale: "pulseScale", pulseDuration: "pulseDuration" }, host: { properties: { "class.dark": "this.dark", "class.light": "this.light", "style.width": "this.width", "style.height": "this.height", "style.--tsl-skeleton-border-radius": "this.borderRadius", "style.--tsl-skeleton-pulse-size": "this.pulseSize", "style.--tsl-skeleton-pulse-scale": "this.pulseScale", "style.--tsl-skeleton-pulse-duration": "this.pulseDuration" } }, ngImport: i0, template: "", styles: [":host{--tsl-skeleton-border-radius: 0px;--tsl-skeleton-pulse-size: 5px;--tsl-skeleton-pulse-duration: 1.25s;--tsl-skeleton-pulse-scale: .98;--tsl-skeleton-color: rgba(0, 0, 0, .15) !important;--tsl-skeleton-pulse-color: rgba(0, 0, 0, .1) !important;--tsl-skeleton-pulse-shadow-color: rgba(0, 0, 0, .1) !important;--tsl-skeleton-pulse-shadow-color-fadeout: rgba(0, 0, 0, 0) !important;display:block;background:var(--tsl-skeleton-color);border-radius:var(--tsl-skeleton-border-radius);height:.65em;width:10em;transform:scale(1);transform-origin:top left;animation:pulse var(--tsl-skeleton-pulse-duration) infinite}:host.dark:not(.light),.dark :host:not(.light){--tsl-skeleton-color: rgba(255, 255, 255, .2) !important;--tsl-skeleton-pulse-color: rgba(255, 255, 255, .15) !important;--tsl-skeleton-pulse-shadow-color: rgba(255, 255, 255, .15) !important;--tsl-skeleton-pulse-shadow-color-fadeout: rgba(255, 255, 255, 0) !important}@keyframes pulse{0%{transform:scale(var(--tsl-skeleton-pulse-scale));background:var(--tsl-skeleton-color);box-shadow:0 0 0 0 var(--tsl-skeleton-pulse-shadow-color)}80%{transform:scale(1);background:var(--tsl-skeleton-pulse-color);box-shadow:0 0 0 var(--tsl-skeleton-pulse-size) var(--tsl-skeleton-pulse-shadow-color-fadeout)}to{transform:scale(var(--tsl-skeleton-pulse-scale));background:var(--tsl-skeleton-color);box-shadow:0 0 0 0 var(--tsl-skeleton-pulse-shadow-color-fadeout)}}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: TstdlSkeletonComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tsl-skeleton', standalone: true, changeDetection: ChangeDetectionStrategy.OnPush, template: "", styles: [":host{--tsl-skeleton-border-radius: 0px;--tsl-skeleton-pulse-size: 5px;--tsl-skeleton-pulse-duration: 1.25s;--tsl-skeleton-pulse-scale: .98;--tsl-skeleton-color: rgba(0, 0, 0, .15) !important;--tsl-skeleton-pulse-color: rgba(0, 0, 0, .1) !important;--tsl-skeleton-pulse-shadow-color: rgba(0, 0, 0, .1) !important;--tsl-skeleton-pulse-shadow-color-fadeout: rgba(0, 0, 0, 0) !important;display:block;background:var(--tsl-skeleton-color);border-radius:var(--tsl-skeleton-border-radius);height:.65em;width:10em;transform:scale(1);transform-origin:top left;animation:pulse var(--tsl-skeleton-pulse-duration) infinite}:host.dark:not(.light),.dark :host:not(.light){--tsl-skeleton-color: rgba(255, 255, 255, .2) !important;--tsl-skeleton-pulse-color: rgba(255, 255, 255, .15) !important;--tsl-skeleton-pulse-shadow-color: rgba(255, 255, 255, .15) !important;--tsl-skeleton-pulse-shadow-color-fadeout: rgba(255, 255, 255, 0) !important}@keyframes pulse{0%{transform:scale(var(--tsl-skeleton-pulse-scale));background:var(--tsl-skeleton-color);box-shadow:0 0 0 0 var(--tsl-skeleton-pulse-shadow-color)}80%{transform:scale(1);background:var(--tsl-skeleton-pulse-color);box-shadow:0 0 0 var(--tsl-skeleton-pulse-size) var(--tsl-skeleton-pulse-shadow-color-fadeout)}to{transform:scale(var(--tsl-skeleton-pulse-scale));background:var(--tsl-skeleton-color);box-shadow:0 0 0 0 var(--tsl-skeleton-pulse-shadow-color-fadeout)}}\n"] }]
        }], propDecorators: { dark: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['class.dark']
            }], light: [{
                type: HostBinding,
                args: ['class.light']
            }], width: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['style.width']
            }], height: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['style.height']
            }], borderRadius: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['style.--tsl-skeleton-border-radius']
            }], pulseSize: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['style.--tsl-skeleton-pulse-size']
            }], pulseScale: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['style.--tsl-skeleton-pulse-scale']
            }], pulseDuration: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['style.--tsl-skeleton-pulse-duration']
            }] } });

class AutoForDirective {
    constructor(elementRef, renderer) {
        this.elementRef = elementRef;
        this.renderer = renderer;
    }
    ngOnChanges() {
        if (isNullOrUndefined(this.autoFor)) {
            this.renderer.removeAttribute(this.elementRef.nativeElement, 'for');
            return;
        }
        this.renderer.setAttribute(this.elementRef.nativeElement, 'for', this.autoFor.id);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: AutoForDirective, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.9", type: AutoForDirective, isStandalone: true, selector: "label, [tslAutoFor]", inputs: { autoFor: "autoFor" }, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: AutoForDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'label, [tslAutoFor]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.Renderer2 }], propDecorators: { autoFor: [{
                type: Input
            }] } });

class AutoIdDirective {
    get id() {
        if (isNullOrUndefined(this.elementRef.nativeElement.id) || (this.elementRef.nativeElement.id.length == 0)) {
            this.elementRef.nativeElement.id = getRandomString(10, Alphabet.LowerCaseNumbers);
            this.renderer.setAttribute(this.elementRef.nativeElement, 'id', this.id);
        }
        return this.elementRef.nativeElement.id;
    }
    constructor(elementRef, renderer) {
        this.elementRef = elementRef;
        this.renderer = renderer;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: AutoIdDirective, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.9", type: AutoIdDirective, isStandalone: true, selector: "input, [tslAutoId]", exportAs: ["autoId"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: AutoIdDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'input, [tslAutoId]',
                    exportAs: 'autoId',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.Renderer2 }] });

class DateInputControlValueAccessor {
    constructor() {
        this.#elementRef = inject(ElementRef);
        this.onTouched = noop;
        this.onChange = noop;
        this.valueType = model('value');
    }
    #elementRef;
    onBlur() {
        this.onTouched();
    }
    onInputChange() {
        this.onChange(this.#elementRef.nativeElement[this.valueType()]);
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    writeValue(value) {
        const valueType = isDate(value)
            ? 'valueAsDate'
            : isNumber(value)
                ? 'valueAsNumber'
                : 'value';
        this.valueType.set(valueType);
        if (valueType == 'valueAsDate') {
            this.#elementRef.nativeElement.valueAsDate = value;
        }
        else if (valueType == 'valueAsNumber') {
            this.#elementRef.nativeElement.valueAsNumber = value;
        }
        else {
            this.#elementRef.nativeElement.value = value;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: DateInputControlValueAccessor, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.9", type: DateInputControlValueAccessor, isStandalone: true, selector: "input[type=date], input[type=datetime-local]", inputs: { valueType: { classPropertyName: "valueType", publicName: "valueType", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { valueType: "valueTypeChange" }, host: { listeners: { "blur": "onBlur()", "input": "onInputChange($event)" } }, providers: [{
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => DateInputControlValueAccessor),
                multi: true
            }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: DateInputControlValueAccessor, decorators: [{
            type: Directive,
            args: [{
                    selector: 'input[type=date], input[type=datetime-local]',
                    standalone: true,
                    providers: [{
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => DateInputControlValueAccessor),
                            multi: true
                        }]
                }]
        }], propDecorators: { onBlur: [{
                type: HostListener,
                args: ['blur', []]
            }], onInputChange: [{
                type: HostListener,
                args: ['input', ['$event']]
            }] } });

class DragDirective {
    constructor() {
        this.clearData = input(false);
        this.allowedEffect = input('uninitialized');
        this.image = input();
        this.imageCoordinates = input();
        this.format = input();
        this.data = input();
        this.start = output();
        this.drag = output();
        this.end = output();
        this.dragging = signal(false);
    }
    onDrag(event) {
        this.drag.emit(event);
    }
    onDragStart(event) {
        this.start.emit(event);
        this.dragging.set(true);
        if (isNull(event.dataTransfer)) {
            return;
        }
        event.dataTransfer.effectAllowed = this.allowedEffect();
        const image = this.image();
        if (isDefined(image)) {
            const [x = 0, y = 0] = this.imageCoordinates() ?? [];
            event.dataTransfer.setDragImage(image, x, y);
        }
        const format = this.format();
        const data = this.data();
        if (this.clearData()) {
            event.dataTransfer.clearData();
        }
        if (isString(data)) {
            event.dataTransfer.setData(format ?? 'text/plain', data);
        }
        else if (isDefined(data)) {
            const entries = objectEntries(data);
            for (const [key, value] of entries) {
                event.dataTransfer.setData(key, value);
            }
        }
    }
    onDragEnd(event) {
        this.end.emit(event);
        this.dragging.set(false);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: DragDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.9", type: DragDirective, isStandalone: true, selector: "[tslDrag]", inputs: { clearData: { classPropertyName: "clearData", publicName: "clearData", isSignal: true, isRequired: false, transformFunction: null }, allowedEffect: { classPropertyName: "allowedEffect", publicName: "allowedEffect", isSignal: true, isRequired: false, transformFunction: null }, image: { classPropertyName: "image", publicName: "image", isSignal: true, isRequired: false, transformFunction: null }, imageCoordinates: { classPropertyName: "imageCoordinates", publicName: "imageCoordinates", isSignal: true, isRequired: false, transformFunction: null }, format: { classPropertyName: "format", publicName: "format", isSignal: true, isRequired: false, transformFunction: null }, data: { classPropertyName: "data", publicName: "data", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { start: "start", drag: "drag", end: "end" }, host: { listeners: { "drag": "onDrag($event)", "dragstart": "onDragStart($event)", "dragend": "onDragEnd($event)" } }, exportAs: ["drag"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: DragDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[tslDrag]',
                    standalone: true,
                    exportAs: 'drag'
                }]
        }], propDecorators: { onDrag: [{
                type: HostListener,
                args: ['drag', ['$event']]
            }], onDragStart: [{
                type: HostListener,
                args: ['dragstart', ['$event']]
            }], onDragEnd: [{
                type: HostListener,
                args: ['dragend', ['$event']]
            }] } });

class DropDirective {
    constructor() {
        this.effect = input();
        this.enter = output();
        this.leave = output();
        this.over = output();
        this.dropped = output();
        this.itemsDropped = output();
        this.filesDropped = output();
        this.entered = signal(false);
        this.isOver = signal(false);
    }
    onDragEnter(event) {
        event.preventDefault();
        const effect = this.effect();
        if (isDefined(effect) && isNotNull(event.dataTransfer)) {
            event.dataTransfer.dropEffect = effect;
        }
        this.enter.emit(event);
        this.entered.set(true);
    }
    onDragOver(event) {
        event.preventDefault();
        this.over.emit(event);
        this.isOver.set(true);
    }
    onDragLeave(event) {
        event.preventDefault();
        this.leave.emit(event);
        this.entered.set(false);
        this.isOver.set(false);
    }
    // Drop listener
    onDrop(event) {
        event.preventDefault();
        this.entered.set(false);
        this.isOver.set(false);
        this.dropped.emit(event);
        if (isNull(event.dataTransfer)) {
            return;
        }
        if (event.dataTransfer.files.length > 0) {
            this.filesDropped.emit(Array.from(event.dataTransfer.files));
        }
        if (event.dataTransfer.items.length > 0) {
            this.itemsDropped.emit(Array.from(event.dataTransfer.items));
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: DropDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.9", type: DropDirective, isStandalone: true, selector: "[tslDrop]", inputs: { effect: { classPropertyName: "effect", publicName: "effect", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { enter: "enter", leave: "leave", over: "over", dropped: "dropped", itemsDropped: "itemsDropped", filesDropped: "filesDropped" }, host: { listeners: { "dragenter": "onDragEnter($event)", "dragover": "onDragOver($event)", "dragleave": "onDragLeave($event)", "drop": "onDrop($event)" } }, exportAs: ["drop"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: DropDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[tslDrop]',
                    standalone: true,
                    exportAs: 'drop'
                }]
        }], propDecorators: { onDragEnter: [{
                type: HostListener,
                args: ['dragenter', ['$event']]
            }], onDragOver: [{
                type: HostListener,
                args: ['dragover', ['$event']]
            }], onDragLeave: [{
                type: HostListener,
                args: ['dragleave', ['$event']]
            }], onDrop: [{
                type: HostListener,
                args: ['drop', ['$event']]
            }] } });

class FilterHelperDirective {
    constructor() {
        this.filterValues = input();
        this.filterSelector = input();
        this.filter = model(null);
        this.normalizedFilterValues = computed(() => {
            const selector = this.filterSelector();
            const valueSelector = isString(selector)
                ? (value) => value[selector]
                : isFunction(selector)
                    ? selector
                    : ((value) => String(value));
            return this.filterValues()?.map((value) => ({ value, searchValue: normalizeText(valueSelector(value)) })) ?? [];
        });
        this.filteredValues = computed(() => {
            const filter = this.filter();
            if (isNull(filter)) {
                return this.filterValues() ?? [];
            }
            const normalizedFilter = normalizeText(filter);
            if (normalizedFilter.length == 0) {
                return this.filterValues() ?? [];
            }
            return this.normalizedFilterValues()
                .filter(({ searchValue }) => searchValue.includes(normalizedFilter))
                .map(({ value }) => value);
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: FilterHelperDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.9", type: FilterHelperDirective, isStandalone: true, selector: "[tslFilterHelper]", inputs: { filterValues: { classPropertyName: "filterValues", publicName: "filterValues", isSignal: true, isRequired: false, transformFunction: null }, filterSelector: { classPropertyName: "filterSelector", publicName: "filterSelector", isSignal: true, isRequired: false, transformFunction: null }, filter: { classPropertyName: "filter", publicName: "filter", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { filter: "filterChange" }, exportAs: ["filterHelper"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: FilterHelperDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[tslFilterHelper]',
                    standalone: true,
                    exportAs: 'filterHelper'
                }]
        }] });

class InputPatternDirective {
    constructor() {
        this.element = inject(ElementRef).nativeElement;
        this.pattern = computed(() => {
            const inputPattern = this.tslInputPattern();
            return isRegExp(inputPattern)
                ? new RegExp(inputPattern, inputPattern.flags) // Hack/workaround for unknown bug or weird behaviour
                : isString(inputPattern)
                    ? new RegExp(inputPattern, 'ug')
                    : undefined;
        });
        this.firstMatchOnly = input(false, { transform: booleanAttribute });
        this.tslInputPattern = input.required();
    }
    ngOnInit() {
        this.onChange();
    }
    onChange() {
        if (this.element.value == this.lastKnownValue) {
            return;
        }
        const pattern = this.pattern();
        if (isUndefined(pattern)) {
            return;
        }
        const matches = [...this.element.value.matchAll(pattern)];
        const result = this.firstMatchOnly()
            ? (matches[0]?.[0] ?? '')
            : matches.map((match) => match[0]).join('');
        this.element.value = result;
        this.lastKnownValue = result;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: InputPatternDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.9", type: InputPatternDirective, isStandalone: true, selector: "input[tslInputPattern]", inputs: { firstMatchOnly: { classPropertyName: "firstMatchOnly", publicName: "firstMatchOnly", isSignal: true, isRequired: false, transformFunction: null }, tslInputPattern: { classPropertyName: "tslInputPattern", publicName: "tslInputPattern", isSignal: true, isRequired: true, transformFunction: null } }, host: { listeners: { "input": "onChange()", "change": "onChange()", "keydown": "onChange()", "keyup": "onChange()", "drop": "onChange()", "paste": "onChange()", "select": "onChange()", "contextmenu": "onChange()", "mousedown": "onChange()", "mouseup": "onChange()" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: InputPatternDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'input[tslInputPattern]',
                    standalone: true
                }]
        }], propDecorators: { onChange: [{
                type: HostListener,
                args: ['input']
            }, {
                type: HostListener,
                args: ['change']
            }, {
                type: HostListener,
                args: ['keydown']
            }, {
                type: HostListener,
                args: ['keyup']
            }, {
                type: HostListener,
                args: ['drop']
            }, {
                type: HostListener,
                args: ['paste']
            }, {
                type: HostListener,
                args: ['select']
            }, {
                type: HostListener,
                args: ['contextmenu']
            }, {
                type: HostListener,
                args: ['mousedown']
            }, {
                type: HostListener,
                args: ['mouseup']
            }] } });

class LazyListDirective extends LifecycleUtils {
    get thresholdReached() {
        if (isUndefined(this.scrollElementSubject.value)) {
            return false;
        }
        const { scrollHeight, scrollTop, clientHeight } = this.scrollElementSubject.value;
        const threshold = Math.max(1, clientHeight * (this.margin / 100));
        return (clientHeight > 0) && ((scrollHeight - scrollTop - clientHeight) <= threshold);
    }
    get hasAll() {
        return this.items.length == this.source.length;
    }
    constructor(elementRef, changeDetector) {
        super();
        this.checking = false;
        const defaultScrollElement = (elementRef.nativeElement instanceof Element) ? elementRef.nativeElement : undefined;
        this.changeDetector = changeDetector;
        this.scrollElementSubject = new BehaviorSubject(defaultScrollElement);
        this.source = [];
        this.initialSize = 1;
        this.batchSize = 1;
        this.margin = 50;
        this.items = [];
        this.scrollElement$ = this.scrollElementSubject.asObservable();
        this.observeElement$ = this.observe('observeElement').pipe(map((observeElement) => ((observeElement instanceof Element) ? observeElement : observeElement?.nativeElement)));
        this.observe('source').subscribe(() => {
            this.items = this.source.slice(0, Math.max(this.initialSize, this.items.length));
            changeDetector.markForCheck();
        });
        this.observe('scrollElement')
            .pipe(map((scrollElement) => ((scrollElement instanceof Element) ? scrollElement : defaultScrollElement)))
            .subscribe(this.scrollElementSubject);
    }
    ngAfterViewInit() {
        super.ngAfterViewInit();
        const resize$ = this.scrollElement$.pipe(switchMap((element) => (isDefined(element) ? observeResize$(element) : EMPTY)), takeUntil(this.destroy$));
        const scroll$ = this.scrollElement$.pipe(switchMap((element) => (isDefined(element) ? fromEvent(element, 'scroll', { passive: true }) : EMPTY)), takeUntil(this.destroy$));
        const intersects$ = combineLatest([this.scrollElement$, this.observeElement$, this.observe('margin')]).pipe(switchMap(([scrollElement, observeElement, margin]) => (isUndefined(observeElement) ? EMPTY : observeIntersection$(observeElement, { root: scrollElement, rootMargin: `${margin}%` }))), takeUntil(this.destroy$), map((entry) => entry.isIntersecting), shareReplay(1));
        const intersect$ = intersects$.pipe(filter((intersects) => intersects));
        this.viewChecked$
            .pipe(take(1), switchMap(() => merge(this.observe('source'), resize$, scroll$, intersect$)))
            .subscribe(() => void this.check());
        intersect$.pipe(switchMap((intersects) => (intersects ? interval(10) : EMPTY)))
            .subscribe(() => this.add());
    }
    async check() {
        if (this.checking) {
            return;
        }
        this.checking = true;
        while (!this.hasAll && this.thresholdReached) {
            this.add();
            await timeout();
        }
        this.checking = false;
    }
    add() {
        if (this.hasAll) {
            return;
        }
        this.items = this.source.slice(0, Math.max(this.initialSize, this.items.length + this.batchSize));
        this.changeDetector.markForCheck();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: LazyListDirective, deps: [{ token: i0.ElementRef }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.9", type: LazyListDirective, isStandalone: true, selector: "[tslLazyList]", inputs: { source: ["tslLazyList", "source"], initialSize: ["lazyInitialSize", "initialSize"], batchSize: ["lazyBatchSize", "batchSize"], margin: ["lazyMargin", "margin"], scrollElement: ["lazyScrollElement", "scrollElement"], observeElement: ["lazyObserveElement", "observeElement"] }, exportAs: ["lazyList"], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: LazyListDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[tslLazyList]',
                    exportAs: 'lazyList',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.ChangeDetectorRef }], propDecorators: { source: [{
                type: Input,
                args: ['tslLazyList']
            }], initialSize: [{
                type: Input,
                args: ['lazyInitialSize']
            }], batchSize: [{
                type: Input,
                args: ['lazyBatchSize']
            }], margin: [{
                type: Input,
                args: ['lazyMargin']
            }], scrollElement: [{
                type: Input,
                args: ['lazyScrollElement']
            }], observeElement: [{
                type: Input,
                args: ['lazyObserveElement']
            }] } });

/**
 * Lazily render the element when it intersects the viewport (default) or specified {@link root} element.
 * {@link rootMargin} (default 25%) and {@link threshold} (0) can be specified.
 * Uses a div of size {@link intrinsicWidth} and {@link intrinsicHeight} to track visibility using {@link IntersectionObserver}
 */
class LazyDirective {
    constructor() {
        this.destroyRef = inject(DestroyRef);
        this.templateRef = inject((TemplateRef));
        this.viewContainer = inject(ViewContainerRef);
        this.elementRef = inject(ElementRef);
        this.renderer = inject(Renderer2);
        this.changeDetector = inject(ChangeDetectorRef);
        this.root = input(undefined, { alias: 'tslLazyRoot' });
        this.rootMargin = input('25%', { alias: 'tslLazyRootMargin' });
        this.threshold = input(undefined, { alias: 'tslLazyThreshold', transform: (value) => isString(value) ? Number(value) : value });
        this.intrinsicWidth = input(undefined, { alias: 'tslLazyIntrinsicWidth' });
        this.intrinsicHeight = input(undefined, { alias: 'tslLazyIntrinsicHeight' });
        /**
         * Template to render before actual deferred view. Useful for eg. for skeletons.
         * Should be lightweight/fast to render
         */
        this.initialTemplate = input(undefined, { alias: 'tslLazyInitialTemplate' });
        /**
         * Insert intersection tracker
         * true: insert even if `initialTemplate` is provided,
         * false: only insert if no initialTemplate is provided (default)
         */
        this.tracker = input(false, { alias: 'tslLazyTracker', transform: booleanAttribute });
        const observerConfig$ = toObservable(computed(() => ({ root: this.root(), rootMargin: this.rootMargin(), threshold: this.threshold() ?? undefined })));
        afterNextRender({
            write: () => {
                const initialTemplate = this.initialTemplate();
                const intrinsicWidth = this.intrinsicWidth();
                const intrinsicHeight = this.intrinsicHeight();
                if (this.tracker() || isUndefined(initialTemplate)) {
                    this.intersectionTracker = this.renderer.createElement('div');
                    if (isDefined(intrinsicWidth)) {
                        this.renderer.setStyle(this.intersectionTracker, 'width', intrinsicWidth);
                    }
                    if (isDefined(intrinsicHeight)) {
                        this.renderer.setStyle(this.intersectionTracker, 'height', intrinsicHeight);
                    }
                    this.renderer.insertBefore(this.elementRef.nativeElement.parentNode, this.intersectionTracker, this.elementRef.nativeElement);
                }
                if (isNotNullOrUndefined(initialTemplate)) {
                    this.initialTemplateView = this.viewContainer.createEmbeddedView(initialTemplate);
                }
                this.changeDetector.markForCheck();
                const intersectionElement = assertDefinedPass(this.intersectionTracker ?? this.initialTemplateView?.rootNodes[0]);
                observerConfig$
                    .pipe(switchMap((config) => observeIntersection$(intersectionElement, config)), filter((intersection) => intersection.isIntersecting), take(1), takeUntilDestroyed(this.destroyRef))
                    .subscribe(() => {
                    this.removeTracker();
                    this.viewContainer.createEmbeddedView(this.templateRef);
                    this.changeDetector.markForCheck();
                });
            }
        });
    }
    ngOnDestroy() {
        this.removeTracker();
    }
    removeTracker() {
        if (isDefined(this.intersectionTracker)) {
            this.renderer.removeChild(this.elementRef.nativeElement.parentNode, this.intersectionTracker);
        }
        if (isDefined(this.initialTemplateView)) {
            this.initialTemplateView.destroy();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: LazyDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.9", type: LazyDirective, isStandalone: true, selector: "[tslLazy]", inputs: { root: { classPropertyName: "root", publicName: "tslLazyRoot", isSignal: true, isRequired: false, transformFunction: null }, rootMargin: { classPropertyName: "rootMargin", publicName: "tslLazyRootMargin", isSignal: true, isRequired: false, transformFunction: null }, threshold: { classPropertyName: "threshold", publicName: "tslLazyThreshold", isSignal: true, isRequired: false, transformFunction: null }, intrinsicWidth: { classPropertyName: "intrinsicWidth", publicName: "tslLazyIntrinsicWidth", isSignal: true, isRequired: false, transformFunction: null }, intrinsicHeight: { classPropertyName: "intrinsicHeight", publicName: "tslLazyIntrinsicHeight", isSignal: true, isRequired: false, transformFunction: null }, initialTemplate: { classPropertyName: "initialTemplate", publicName: "tslLazyInitialTemplate", isSignal: true, isRequired: false, transformFunction: null }, tracker: { classPropertyName: "tracker", publicName: "tslLazyTracker", isSignal: true, isRequired: false, transformFunction: null } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: LazyDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[tslLazy]',
                    standalone: true
                }]
        }], ctorParameters: () => [] });

class LetDirective {
    constructor() {
        this.template = inject(TemplateRef);
        this.viewContainer = inject(ViewContainerRef);
        this.changeDetector = inject(ChangeDetectorRef);
        this.injector = inject(Injector);
        this.errorHandler = inject(ErrorHandler);
        this.inputSubject = new ReplaySubject(1);
        this.viewContext = {
            $implicit: undefined,
            tslLet: undefined,
            isComplete: false,
            hasError: false,
            error: undefined
        };
        this.subscription = this.inputSubject.pipe(switchMap((input) => {
            this.viewContext.isComplete = false;
            this.viewContext.hasError = false;
            this.viewContext.error = undefined;
            const observable = isAsyncInput(input)
                ? (isFunction(input) && isSignal(input))
                    ? toObservable(input, { injector: this.injector })
                    : from(input)
                : of(input);
            return observable.pipe(tap({
                next: (value) => this.next(value),
                error: (error) => this.error(error),
                complete: () => this.complete()
            }), catchError((error) => {
                this.errorHandler.handleError(error);
                return EMPTY;
            }));
        }), distinctUntilChanged()).subscribe((value) => {
            this.viewContext.$implicit = value;
            this.viewContext.tslLet = value;
        });
    }
    set tslLet(observableInput) {
        this.inputSubject.next(observableInput);
    }
    static ngTemplateContextGuard(_directive, _context) {
        return true;
    }
    next(value) {
        this.viewContext.$implicit = value;
        this.viewContext.tslLet = value;
        this.updateEmbeddedView();
    }
    error(error) {
        this.viewContext.hasError = true;
        this.viewContext.error = error;
        this.updateEmbeddedView();
    }
    complete() {
        this.viewContext.isComplete = true;
        this.updateEmbeddedView();
    }
    updateEmbeddedView() {
        if (isUndefined(this.embeddedView)) {
            this.embeddedView = this.viewContainer.createEmbeddedView(this.template, this.viewContext);
        }
        this.changeDetector.markForCheck();
    }
    ngOnDestroy() {
        this.inputSubject.complete();
        this.subscription.unsubscribe();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: LetDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.9", type: LetDirective, isStandalone: true, selector: "[tslLet]", inputs: { tslLet: "tslLet" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: LetDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[tslLet]',
                    standalone: true
                }]
        }], propDecorators: { tslLet: [{
                type: Input
            }] } });
function isAsyncInput(value) {
    return isObservable(value)
        || isAsyncIterable(value)
        || isFunction(value?.then) // eslint-disable-line @typescript-eslint/unbound-method
        || isFunction(value?.getReader) // eslint-disable-line @typescript-eslint/unbound-method
        || isSignal(value);
}

/**
 * Wrapper for angulars {@link resource} which raises errors to {@link ErrorHandler}
 * @param options
 * @returns
 */
function errorHandledResource(options) {
    const errorHandler = inject(ErrorHandler);
    const ref = resource(options);
    effect(() => {
        if (ref.status() != ResourceStatus.Error) {
            return;
        }
        const error = ref.error();
        if (isNotNullOrUndefined(error)) {
            errorHandler.handleError(error);
        }
    }, { injector: options.injector });
    return ref;
}

function routeData(definition) {
    return definition;
}

function numberTransform(value) {
    if (isNull(value)) {
        return null;
    }
    const number = Number(value);
    if (Number.isNaN(number)) {
        return null;
    }
    return number;
}
function booleanTransform(value) {
    if ((value === true) || (value === 'true') || (value === 1)) {
        return true;
    }
    if ((value === false) || (value === 'false') || (value === 0)) {
        return false;
    }
    return null;
}
function numberTransformWithFallback(fallback) {
    return (value) => numberTransform(value) ?? fallback;
}
function booleanTransformWithFallback(fallback) {
    return (value) => booleanTransform(value) ?? fallback;
}

class RepeatDirective extends LifecycleUtils {
    constructor(templateRef, viewContainer, changeDetector) {
        super();
        this.tslRepeat = 1;
        this.init$
            .pipe(switchMap(() => this.observe('tslRepeat')))
            .subscribe((repeat) => {
            while (viewContainer.length > repeat) {
                viewContainer.remove();
            }
            while (repeat > viewContainer.length) {
                viewContainer.createEmbeddedView(templateRef, { $implicit: viewContainer.length, index: viewContainer.length });
            }
            changeDetector.markForCheck();
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: RepeatDirective, deps: [{ token: i0.TemplateRef }, { token: i0.ViewContainerRef }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.9", type: RepeatDirective, isStandalone: true, selector: "[tslRepeat]", inputs: { tslRepeat: "tslRepeat" }, usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: RepeatDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[tslRepeat]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.TemplateRef }, { type: i0.ViewContainerRef }, { type: i0.ChangeDetectorRef }], propDecorators: { tslRepeat: [{
                type: Input
            }] } });

class VisibilityObserverDirective {
    get isVisible() {
        return this.isVisibleSubject.value;
    }
    get visibility() {
        return this.visibilitySubject.value;
    }
    constructor(elementRef, renderer) {
        this.elementRef = elementRef;
        this.renderer = renderer;
        this.treshold = 0.05;
        this.margin = '0px';
        this.root = null;
        this.isVisibleSubject = new BehaviorSubject(false);
        this.visibilitySubject = new BehaviorSubject(0);
        this.visible = new EventEmitter();
        this.isVisibleChanged = new EventEmitter();
        this.visibilityChanged = new EventEmitter();
        this.isVisible$ = this.isVisibleSubject.asObservable();
        this.visibility$ = this.visibilitySubject.asObservable();
        this.isVisibleSubject.pipe(filter((visible) => visible), map(() => this.elementRef)).subscribe(this.visible);
        this.isVisible$.subscribe(this.isVisibleChanged);
        this.visibility$.subscribe(this.visibilityChanged);
    }
    ngOnInit() {
        this.setupObserver();
    }
    ngOnChanges(changes) {
        if ('treshold' in changes || 'margin' in changes || 'parent' in changes) {
            this.setupObserver();
        }
    }
    onObserve(entries) {
        const entry = entries[0];
        this.visibilitySubject.next(entry.intersectionRatio);
        this.isVisibleSubject.next(entry.isIntersecting);
        if (isDefined(this.dataAttribute) && this.dataAttribute.length > 0) {
            setTimeout(() => this.renderer.setAttribute(this.elementRef.nativeElement, `data-${this.dataAttribute}`, entry.isIntersecting.toString()), 50);
        }
    }
    ngOnDestroy() {
        this.unobserve();
        this.isVisibleSubject.complete();
        this.visibilitySubject.complete();
    }
    setupObserver() {
        this.unobserve();
        let root = isNullOrUndefined(this.root)
            ? null
            : isNumber(this.root)
                ? this.elementRef.nativeElement
                : this.root;
        if (isNumber(this.root)) {
            for (let i = 0; i < this.root; i++) {
                root = root.parentElement;
                if (isNull(root)) {
                    throw new Error(`parent element ${this.root} levels above not available`);
                }
            }
        }
        this.observer = new IntersectionObserver((entries) => this.onObserve(entries), { threshold: this.treshold, rootMargin: this.margin, root });
        this.observer.observe(this.elementRef.nativeElement);
    }
    unobserve() {
        if (isUndefined(this.observer)) {
            return;
        }
        this.observer.unobserve(this.elementRef.nativeElement);
        this.observer.disconnect();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: VisibilityObserverDirective, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.9", type: VisibilityObserverDirective, isStandalone: true, selector: "[visibilityObserver]", inputs: { dataAttribute: ["visibilityObserver", "dataAttribute"], treshold: ["visibilityTreshold", "treshold"], margin: ["visibilityMargin", "margin"], root: ["visibilityRoot", "root"] }, outputs: { visible: "visible", isVisibleChanged: "isVisibleChanged", visibilityChanged: "visibilityChanged" }, exportAs: ["visibilityObserver"], usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: VisibilityObserverDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[visibilityObserver]',
                    exportAs: 'visibilityObserver',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.Renderer2 }], propDecorators: { dataAttribute: [{
                type: Input,
                args: ['visibilityObserver']
            }], treshold: [{
                type: Input,
                args: ['visibilityTreshold']
            }], margin: [{
                type: Input,
                args: ['visibilityMargin']
            }], root: [{
                type: Input,
                args: ['visibilityRoot']
            }], visible: [{
                type: Output
            }], isVisibleChanged: [{
                type: Output
            }], visibilityChanged: [{
                type: Output
            }] } });

const aborted = Symbol('aborted');
let AngularHttpClientAdapter = class AngularHttpClientAdapter {
    constructor() {
        this.angularHttpClient = inject(HttpClient);
    }
    async call(request) {
        try {
            const angularResponse = await firstValueFrom(race(this.angularHttpClient.request(request.method, request.url, {
                headers: new HttpHeaders(request.headers.asNormalizedObject()),
                responseType: 'blob',
                observe: 'response',
                body: getAngularBody(request.body),
                withCredentials: (request.credentials == 'same-origin') || (request.credentials == 'include')
            }), request.abortSignal.set$.pipe(switchMap(() => throwError(() => aborted)))));
            const headers = convertAngularHeaders(angularResponse.headers);
            const response = new HttpClientResponse({
                request,
                statusCode: angularResponse.status,
                statusMessage: angularResponse.statusText,
                headers,
                body: angularResponse.body ?? undefined,
                closeHandler: () => request.abort()
            });
            return response;
        }
        catch (error) {
            if (error == aborted) {
                throw new HttpError(HttpErrorReason.Cancelled, request);
            }
            if (!(error instanceof HttpErrorResponse)) {
                throw new HttpError(HttpErrorReason.Unknown, request, undefined, undefined, error);
            }
            const response = new HttpClientResponse({
                request,
                statusCode: error.status,
                statusMessage: error.statusText,
                headers: convertAngularHeaders(error.headers),
                body: (error.error instanceof ProgressEvent) ? undefined : error.error,
                closeHandler: () => request.abort()
            });
            if ((error.type == HttpEventType.Response) && (error.status > 0)) {
                return response;
            }
            const reason = getHttpErrorReason(error);
            const httpError = await HttpError.create(reason, request, response, error);
            throw httpError;
        }
    }
};
AngularHttpClientAdapter = __decorate([
    Singleton()
], AngularHttpClientAdapter);
function getHttpErrorReason(error) {
    const statusText = error.statusText.toLowerCase();
    if (statusText.includes('timeout')) {
        return HttpErrorReason.Timeout;
    }
    return HttpErrorReason.Unknown;
}
function convertAngularHeaders(headers) {
    const headersObject = Object.fromEntries(headers.keys().map((name) => [name, headers.getAll(name)]).map(([name, values]) => [name, values.length > 1 ? values : values[0]]));
    return new HttpHeaders$1(headersObject);
}
function getAngularBody(body) {
    if (isUndefined(body)) {
        return null;
    }
    if (isDefined(body.json)) {
        return JSON.stringify(body.json);
    }
    if (isDefined(body.text)) {
        return body.text;
    }
    if (isDefined(body.binary)) {
        if (isBlob(body.binary)) {
            return body.binary;
        }
        if (isUint8Array(body.binary)) {
            return new Blob([body.binary]);
        }
        if (isReadableStream(body.binary)) {
            throw new Error('AngularHttpClientAdapter does not support streams. Use buffer instead.');
        }
    }
    if (isDefined(body.form)) {
        const params = new URLSearchParams();
        for (const [key, entry] of body.form.normalizedEntries()) {
            for (const value of toArray(entry)) {
                params.append(key, value);
            }
        }
        return params.toString();
    }
    if (isDefined(body.formData)) {
        return body.formData;
    }
    throw new Error('Unsupported body.');
}
function isApiClientHttpRequestContext(context) {
    return hasOwnProperty(context, 'endpoint');
}
function configureAngularHttpClientAdapter() {
    Injector$1.register(HttpClientAdapter, { useToken: AngularHttpClientAdapter });
    Injector$1.register(HttpClient, { useFactory: (_, context) => context.resolve(Injector).get(HttpClient) });
}

class DateTimeLocalePipe {
    transform(input, format, options) {
        if (isNullOrUndefined(input)) {
            return null;
        }
        const dateTime = toDateTime(input);
        const formatOptions = (typeof format == 'string')
            ? DateTime[format]
            : format;
        return dateTime.toLocaleString(formatOptions, options);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: DateTimeLocalePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: DateTimeLocalePipe, isStandalone: true, name: "dateTimeLocale" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: DateTimeLocalePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'dateTimeLocale',
                    standalone: true
                }]
        }] });

class DateTimeToDatePipe {
    transform(value) {
        if (isNullOrUndefined(value)) {
            return null;
        }
        return value.toJSDate();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: DateTimeToDatePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: DateTimeToDatePipe, isStandalone: true, name: "dateTimeToDate" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: DateTimeToDatePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'dateTimeToDate',
                    standalone: true
                }]
        }] });

class DateTimePipe {
    transform(input, format, options) {
        if (isNullOrUndefined(input)) {
            return null;
        }
        const dateTime = toDateTime(input);
        return dateTime.toFormat(format, options);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: DateTimePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: DateTimePipe, isStandalone: true, name: "dateTime" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: DateTimePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'dateTime',
                    standalone: true
                }]
        }] });

class DecyclePipe {
    transform(value, replacer) {
        return decycle(value, replacer);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: DecyclePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: DecyclePipe, isStandalone: true, name: "decycle" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: DecyclePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'decycle',
                    standalone: true
                }]
        }] });

class DurationPipe {
    transform(millisecondsOrObject, format, options, formatOptions) {
        if (isNullOrUndefined(millisecondsOrObject)) {
            return null;
        }
        const duration = isNumber(millisecondsOrObject)
            ? Duration.fromMillis(millisecondsOrObject, options)
            : millisecondsOrObject instanceof Duration
                ? millisecondsOrObject
                : Duration.fromObject(millisecondsOrObject, options);
        return duration.toFormat(format, formatOptions);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: DurationPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: DurationPipe, isStandalone: true, name: "duration" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: DurationPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'duration',
                    standalone: true
                }]
        }] });

class DynamicTextPipe {
    #injector = inject(Injector);
    #localizationService = inject(LocalizationService);
    #text = signal(undefined, { equal: strictEquals });
    #result = switchAll(() => {
        const text = this.#text();
        return isNull(text)
            ? computed(() => null)
            : runInInjectionContext(this.#injector, () => resolveDynamicText(text ?? missingLocalizationKeyText, this.#localizationService));
    });
    transform(value) {
        untracked(() => this.#text.set(value));
        return this.#result();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: DynamicTextPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: DynamicTextPipe, isStandalone: true, name: "dynamicText", pure: false }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: DynamicTextPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'dynamicText',
                    pure: false,
                    standalone: true
                }]
        }] });

class LocalizeEnumPipe {
    #localizationService = inject(LocalizationService);
    #enumeration = signal(null, { equal: strictEquals });
    #value = signal(null, { equal: strictEquals });
    #parameters = signal(undefined, { equal: strictEquals });
    #result = switchAll(() => {
        const enumeration = this.#enumeration();
        if (isNotNull(enumeration)) {
            return this.#localizationService.localizeEnum(enumeration, this.#value() ?? undefined, this.#parameters());
        }
        return computed(() => '[MISSING LOCALIZATION KEY]');
    });
    transform(enumerationOrValue, enumerationOrParameters, parametersOrNothing) {
        if (isNullOrUndefined(enumerationOrValue)) {
            this.updateInputs(null, null);
            return null;
        }
        if (isObject(enumerationOrValue)) {
            this.updateInputs(enumerationOrValue, null, enumerationOrParameters);
        }
        else {
            if (isNullOrUndefined(enumerationOrParameters)) {
                this.updateInputs(null, null);
                return null;
            }
            this.updateInputs(enumerationOrParameters, enumerationOrValue, parametersOrNothing);
        }
        return this.#result();
    }
    updateInputs(enumeration, value, parameters = undefined) {
        untracked(() => {
            this.#enumeration.set(enumeration);
            this.#value.set(value);
            this.#parameters.set(parameters);
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: LocalizeEnumPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: LocalizeEnumPipe, isStandalone: true, name: "localizeEnum", pure: false }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: LocalizeEnumPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'localizeEnum',
                    pure: false,
                    standalone: true
                }]
        }] });

class LocalizePipe {
    #localizationService = inject(LocalizationService);
    #transformKey = signal(null, { equal: strictEquals });
    #transformParameters = signal(undefined, { equal: strictEquals });
    #transformData = signal(null, { equal: strictEquals });
    #result = switchAll(() => {
        const data = this.#transformData();
        if (isNotNull(data)) {
            return this.#localizationService.localize(data);
        }
        const key = this.#transformKey();
        if (isNull(key)) {
            return computed(() => '[MISSING LOCALIZATION KEY]');
        }
        return this.#localizationService.localize({ key, parameters: this.#transformParameters() });
    });
    transform(localizationDataOrKey, parametersOrNothing) {
        if (isNullOrUndefined(localizationDataOrKey)) {
            this.updateInputs(null, null);
            return null;
        }
        if (isString(localizationDataOrKey) || isProxyLocalizationKey(localizationDataOrKey)) {
            this.updateInputs(null, localizationDataOrKey, parametersOrNothing);
        }
        else {
            this.updateInputs(localizationDataOrKey, null);
        }
        return this.#result();
    }
    updateInputs(data, key, parameters = undefined) {
        untracked(() => {
            this.#transformData.set(data);
            this.#transformKey.set(key);
            this.#transformParameters.set(parameters);
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: LocalizePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: LocalizePipe, isStandalone: true, name: "localize", pure: false }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: LocalizePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'localize',
                    pure: false,
                    standalone: true
                }]
        }] });

class NumberLocalePipe {
    transform(value, localesOrOptions, optionsOrNothing) {
        if (isNullOrUndefined(value)) {
            return null;
        }
        const localesProvided = isString(localesOrOptions) || isArray(localesOrOptions);
        const locales = localesProvided ? localesOrOptions : navigator.languages;
        const options = (localesProvided ? optionsOrNothing : localesOrOptions) ?? undefined;
        return new Intl.NumberFormat(locales, options).format(value);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: NumberLocalePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: NumberLocalePipe, isStandalone: true, name: "numberLocale" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: NumberLocalePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'numberLocale',
                    standalone: true
                }]
        }] });

class NumericDateToDateTimePipe {
    transform(value, options) {
        if (isNullOrUndefined(value)) {
            return null;
        }
        return numericDateToDateTime(value, undefined, options);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: NumericDateToDateTimePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: NumericDateToDateTimePipe, isStandalone: true, name: "numericDateToDateTime" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: NumericDateToDateTimePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'numericDateToDateTime',
                    standalone: true
                }]
        }] });

class NumericTimeToDateTimePipe {
    transform(numericTime, options) {
        if (isNullOrUndefined(numericTime)) {
            return null;
        }
        const timeObject = numericTimeToTimeObject(numericTime);
        if (Number.isNaN(timeObject.hour)) {
            return DateTime.invalid('NaN time');
        }
        return DateTime.fromObject(timeObject, options);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: NumericTimeToDateTimePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: NumericTimeToDateTimePipe, isStandalone: true, name: "numericTimeToDateTime" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: NumericTimeToDateTimePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'numericTimeToDateTime',
                    standalone: true
                }]
        }] });

class OptionalLocalizePipe extends LocalizePipe {
    transform(localizationDataOrKeyOrString, parametersOrNothing) {
        if (isString(localizationDataOrKeyOrString)) {
            super.transform(null);
            return localizationDataOrKeyOrString;
        }
        return super.transform(localizationDataOrKeyOrString, parametersOrNothing);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: OptionalLocalizePipe, deps: null, target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: OptionalLocalizePipe, isStandalone: true, name: "optionalLocalize", pure: false }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: OptionalLocalizePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'optionalLocalize',
                    pure: false,
                    standalone: true
                }]
        }] });

class PadPipe {
    transform(input, length, fillString = ' ', position = 'start') {
        const inputType = typeof input;
        if (inputType != 'string' && inputType != 'number') {
            throw new Error(`Padding for type ${inputType} not supported.`);
        }
        const text = inputType == 'string' ? input : input.toString();
        const pad = position == 'start' ? String.prototype.padStart.bind(text) : String.prototype.padEnd.bind(text);
        return pad(length, fillString.toString());
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: PadPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: PadPipe, isStandalone: true, name: "pad" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: PadPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'pad',
                    standalone: true
                }]
        }] });

class SafeHtmlPipe {
    constructor(domSanitizer) {
        this.domSanitizer = domSanitizer;
    }
    transform(html) {
        if (isNullOrUndefined(html)) {
            return null;
        }
        return this.domSanitizer.bypassSecurityTrustHtml(html);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: SafeHtmlPipe, deps: [{ token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: SafeHtmlPipe, isStandalone: true, name: "safeHtml" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: SafeHtmlPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'safeHtml',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i1.DomSanitizer }] });

class SafeResourceUrlPipe {
    constructor(domSanitizer) {
        this.domSanitizer = domSanitizer;
    }
    transform(url) {
        if (isNullOrUndefined(url)) {
            return null;
        }
        return this.domSanitizer.bypassSecurityTrustResourceUrl(url);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: SafeResourceUrlPipe, deps: [{ token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: SafeResourceUrlPipe, isStandalone: true, name: "safeResourceUrl" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: SafeResourceUrlPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'safeResourceUrl',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i1.DomSanitizer }] });

class SafeUrlPipe {
    constructor(domSanitizer) {
        this.domSanitizer = domSanitizer;
    }
    transform(url) {
        if (isNullOrUndefined(url)) {
            return null;
        }
        return this.domSanitizer.bypassSecurityTrustUrl(url);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: SafeUrlPipe, deps: [{ token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: SafeUrlPipe, isStandalone: true, name: "safeUrl" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: SafeUrlPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'safeUrl',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i1.DomSanitizer }] });

class SanitizePipe {
    constructor(domSanitizer) {
        this.domSanitizer = domSanitizer;
    }
    transform(url, context) {
        return this.domSanitizer.sanitize(context, url ?? null);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: SanitizePipe, deps: [{ token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: SanitizePipe, isStandalone: true, name: "sanitize" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: SanitizePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'sanitize',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i1.DomSanitizer }] });

class SerializePipe {
    transform(value, options) {
        return serialize(value, options);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: SerializePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: SerializePipe, isStandalone: true, name: "serialize" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: SerializePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'serialize',
                    standalone: true
                }]
        }] });

class ToObservablePipe {
    constructor() {
        this.injector = inject(Injector);
    }
    transform(source) {
        if (source != this.source) {
            this.source = source;
            this.observable = toObservable(source, { injector: this.injector });
        }
        return this.observable;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: ToObservablePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: ToObservablePipe, isStandalone: true, name: "toObservable" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: ToObservablePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'toObservable',
                    standalone: true
                }]
        }] });

function waitForAppStabilization(appStabilizationService) {
    return function waitForAppStabilization(source) {
        return appStabilizationService.wait$().pipe(switchMap(() => source)); // eslint-disable-line @typescript-eslint/no-unsafe-argument
    };
}

/* eslint-disable @typescript-eslint/no-shadow */
function runInZone(zone) {
    return function runInZone(source) {
        return new Observable((subscriber) => source.subscribe({
            next: (state) => zone.run(() => subscriber.next(state)),
            complete: () => zone.run(() => subscriber.complete()),
            error: (error) => zone.run(() => subscriber.error(error))
        }));
    };
}
function runOutsideAngular(zone) {
    return function runOutsideAngular(source) {
        return new Observable((subscriber) => source.subscribe({
            next: (state) => zone.runOutsideAngular(() => subscriber.next(state)),
            complete: () => zone.runOutsideAngular(() => subscriber.complete()),
            error: (error) => zone.runOutsideAngular(() => subscriber.error(error))
        }));
    };
}
function runTaskInZone(zone) {
    return function runTaskInZone(source) {
        return new Observable((subscriber) => source.subscribe({
            next: (state) => zone.runTask(() => subscriber.next(state)),
            complete: () => zone.runTask(() => subscriber.complete()),
            error: (error) => zone.runTask(() => subscriber.error(error))
        }));
    };
}
function runGuardedInZone(zone) {
    return function runGuardedInZone(source) {
        return new Observable((subscriber) => source.subscribe({
            next: (state) => zone.runGuarded(() => subscriber.next(state)),
            complete: () => zone.runGuarded(() => subscriber.complete()),
            error: (error) => zone.runGuarded(() => subscriber.error(error))
        }));
    };
}

class AppStabilizationService {
    constructor(applicationRef, ngZone) {
        this.applicationRef = applicationRef;
        this.ngZone = ngZone;
        this.state$ = this.getStateObservable();
    }
    wait$(state = true) {
        return this.state$.pipe(first((isStable) => isStable == state), map(() => undefined));
    }
    async wait(state = true) {
        return firstValueFrom(this.wait$(state));
    }
    getStateObservable() {
        return this.applicationRef.isStable.pipe(runInZone(this.ngZone), distinctUntilChanged(), shareReplay({ bufferSize: 1, refCount: true }));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: AppStabilizationService, deps: [{ token: i0.ApplicationRef }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: AppStabilizationService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: AppStabilizationService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: i0.ApplicationRef }, { type: i0.NgZone }] });

class ApplicationTickService {
    constructor() {
        this.applicationRef = inject(ApplicationRef);
        this.scheduled = false;
    }
    schedule() {
        if (!this.scheduled) {
            requestAnimationFrame(() => {
                this.scheduled = false;
                this.applicationRef.tick();
            });
            this.scheduled = true;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: ApplicationTickService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: ApplicationTickService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: ApplicationTickService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

/* eslint-disable @typescript-eslint/no-unsafe-member-access */
class ErrorHandlerServiceOptions {
}
const defaultFormatErrorOptions = { includeName: false, includeRest: false, includeStack: false };
class ErrorHandlerMessageService {
    constructor() {
        this.#injector = inject(Injector);
        this.format = { ...defaultFormatErrorOptions, ...inject(ErrorHandlerServiceOptions, { optional: true })?.format };
    }
    #injector;
    #_localizationService;
    get #localizationService() {
        if (isUndefined(this.#_localizationService)) {
            this.#_localizationService = this.#injector.get(LocalizationService);
        }
        return this.#_localizationService;
    }
    getErrorMessage(error) {
        const actualError = unwrapError(error);
        if ((actualError instanceof CustomError)) {
            const errorLocalizationKey = tstdlErrorsLocalizationKeys.errors[actualError.constructor.errorName];
            const headerLocalizationKey = errorLocalizationKey.header;
            const messageLocalizationKey = errorLocalizationKey.message;
            const hasHeader = this.#localizationService.hasKey(headerLocalizationKey);
            const hasMessage = this.#localizationService.hasKey(messageLocalizationKey ?? '');
            if (hasHeader || hasMessage) {
                return {
                    header: hasMessage ? { key: headerLocalizationKey, parameters: actualError } : undefined,
                    message: { key: messageLocalizationKey ?? headerLocalizationKey, parameters: actualError }
                };
            }
        }
        return {
            header: (actualError instanceof Error) ? actualError.name : undefined,
            message: formatError(actualError, this.format)
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: ErrorHandlerMessageService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: ErrorHandlerMessageService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: ErrorHandlerMessageService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

class NotificationService {
}
function messageBoxTextInput(input) {
    return { type: 'text', ...input };
}
function messageBoxTextAreaInput(input) {
    return { type: 'text-area', ...input };
}
function messageBoxSelectInput(input) {
    return { type: 'select', ...input };
}
function isMessageBoxTextInput(input) {
    return input.type == 'text';
}
function isMessageBoxTextAreaInput(input) {
    return input.type == 'text-area';
}
function isMessageBoxSelectInput(input) {
    return input.type == 'select';
}

class ErrorHandlerService {
    constructor() {
        this.notificationService = inject(NotificationService);
        this.errorHandlerMessageService = inject(ErrorHandlerMessageService);
        this.logger = inject(Logger);
        this.errorSubject = new Subject();
        this.notifiedErrors = new WeakSet();
        this.error$ = this.errorSubject.asObservable();
    }
    handleError$() {
        return catchError((error) => {
            this.handleError(error);
            return throwError(() => error);
        });
    }
    // eslint-disable-next-line max-statements
    handleError(error) {
        this.logger.error(error, { includeRest: true, includeStack: true });
        this.errorSubject.next(error);
        const errorType = typeof error;
        if ((errorType == 'function') || (errorType == 'object' && isNotNull(error))) {
            if (this.notifiedErrors.has(error)) {
                return;
            }
            this.notifiedErrors.add(error);
        }
        const notificationData = this.errorHandlerMessageService.getErrorMessage(error);
        this.notificationService.notify({ type: 'error', ...notificationData });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: ErrorHandlerService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: ErrorHandlerService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: ErrorHandlerService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

class RoutingService {
    constructor() {
        this.router = inject(Router);
        this.route = inject(ActivatedRoute);
    }
    async setQueryParameter(key, value) {
        return this.setQueryParameters({ [key]: value });
    }
    async setQueryParameters(parameters, options) {
        await this.router.navigate([], {
            queryParams: parameters,
            queryParamsHandling: options?.queryParamsHandling ?? 'merge'
        });
    }
    async setFragment(value) {
        await this.router.navigate([], {
            fragment: value ?? '',
            queryParamsHandling: 'preserve'
        });
    }
}
function injectRoutingService() {
    return new RoutingService();
}
function injectParameter(parameter, options) {
    return toSignal(injectParameter$(parameter, options), { requireSync: true });
}
function injectParameter$(parameter, options) {
    const observable = getParameterFromAll$(parameter);
    const result = (options?.optional == true)
        ? observable
        : observable.pipe(map((value) => assertStringPass(value, `Missing ${parameter} in route parameters.`)));
    return result;
}
function injectParameters(parameter) {
    return toSignal(injectParameters$(parameter), { requireSync: true });
}
function injectParameters$(parameter) {
    return getParametersFromAll$(parameter);
}
function injectQueryParameter(parameter, options) {
    const routingService = injectRoutingService();
    const errorHandler = inject(ErrorHandler);
    const transformFromString = isFunction(options?.transform) ? options.transform : options?.transform?.fromString;
    const transformToString = ((isDefined(options?.transform) && isNotFunction(options.transform)) ? options.transform.toString : undefined) ?? ((value) => isNull(value) ? null : String(value));
    const parameterSignal = toSignal(injectQueryParameter$(parameter), { requireSync: true });
    const signal = linkedSignal(isDefined(transformFromString) ? () => transformFromString(parameterSignal()) : parameterSignal);
    if (isNotNull(routingService.route)) {
        effect(() => {
            void routingService.setQueryParameter(parameter, transformToString(signal())).catch((error) => errorHandler.handleError(error));
        });
    }
    return signal;
}
function injectQueryParameter$(parameter) {
    return inject(ActivatedRoute).queryParamMap.pipe(map((value) => value.get(parameter)));
}
function injectQueryParameters(parameter, options) {
    const routingService = injectRoutingService();
    const errorHandler = inject(ErrorHandler);
    const transformFromString = isFunction(options?.transform) ? options.transform : options?.transform?.fromString;
    const transformToString = ((isDefined(options?.transform) && isNotFunction(options.transform)) ? options.transform.toString : undefined) ?? ((value) => isArray(value) ? value.map(String) : isNull(value) ? null : String(value));
    const parameterSignal = toSignal(injectQueryParameters$(parameter), { requireSync: true });
    const signal = linkedSignal(isDefined(transformFromString) ? () => transformFromString(parameterSignal()) : parameterSignal);
    if (isNotNull(routingService.route)) {
        effect(() => {
            const value = signal();
            void routingService.setQueryParameter(parameter, isArray(value) ? value.map(String) : transformToString(value)).catch((error) => errorHandler.handleError(error));
        });
    }
    return signal;
}
function injectQueryParameters$(parameter) {
    return inject(ActivatedRoute).queryParamMap.pipe(map((value) => value.getAll(parameter)));
}
function injectFragmet() {
    const routingService = injectRoutingService();
    const errorHandler = inject(ErrorHandler);
    const parameterSignal = toSignal(injectFragmet$(), { requireSync: true });
    const signal = linkedSignal(parameterSignal);
    effect(() => void routingService.setFragment(signal()).catch((error) => errorHandler.handleError(error)));
    return signal;
}
function injectFragmet$() {
    return inject(ActivatedRoute).fragment;
}
function injectRouteData() {
    return toSignal(injectRouteData$(), { requireSync: true });
}
function injectRouteData$() {
    return inject(ActivatedRoute).data;
}
function getParameterFromAll$(parameter, route = inject(ActivatedRoute)) {
    const path = getRoutePath(route);
    const paramMaps = path.map((r) => r.paramMap);
    return combineLatest(paramMaps).pipe(map((maps) => {
        for (const paramMap of maps) {
            const value = paramMap.get(parameter);
            if (isNotNull(value)) {
                return value;
            }
        }
        return null;
    }));
}
function getParametersFromAll$(parameter, route = inject(ActivatedRoute)) {
    const path = getRoutePath(route);
    const paramMaps = path.map((r) => r.paramMap);
    return combineLatest(paramMaps).pipe(map((maps) => {
        for (const paramMap of maps) {
            const values = paramMap.getAll(parameter);
            if (values.length > 0) {
                return values;
            }
        }
        return [];
    }));
}
function getRoutePath(route) {
    const routes = [route];
    while (true) {
        const currentRoute = routes.at(-1);
        if (isNull(currentRoute.parent)) {
            return routes;
        }
        routes.push(currentRoute.parent);
    }
}

class WrappedR3InjectorRecordsMap {
    #injector;
    #processingProvider = false;
    get size() {
        return this.records.size;
    }
    get [Symbol.toStringTag]() {
        return this.records[Symbol.toStringTag];
    }
    constructor(injector, r3Injector, records) {
        this.#injector = injector;
        this.r3Injector = r3Injector;
        this.records = records;
    }
    static wrap(injector, r3Injector) {
        r3Injector.records = new WrappedR3InjectorRecordsMap(injector, r3Injector, r3Injector.records);
    }
    clear() {
        this.records.clear();
    }
    delete(key) {
        return this.records.delete(key);
    }
    forEach(callbackfn, thisArg) {
        const _this = this; // eslint-disable-line consistent-this, @typescript-eslint/no-this-alias
        function callback(value, key) {
            callbackfn(value, key, _this);
        }
        this.records.forEach(callback, thisArg);
    }
    get(key) {
        this.addIfPossible(key);
        return this.records.get(key);
    }
    has(key) {
        this.addIfPossible(key);
        return this.records.has(key);
    }
    set(key, value) {
        this.records.set(key, value);
        return this;
    }
    entries() {
        return this.records.entries();
    }
    keys() {
        return this.records.keys();
    }
    values() {
        return this.records.values();
    }
    [Symbol.iterator]() {
        return this.records[Symbol.iterator]();
    }
    addIfPossible(key) {
        if (this.#processingProvider) {
            return;
        }
        try {
            this.#processingProvider = true;
            if (!this.records.has(key) && this.#injector.hasRegistration(key)) {
                this.r3Injector.processProvider({ provide: key, useFactory: () => this.#injector.resolve(key) });
            }
        }
        finally {
            this.#processingProvider = false;
        }
    }
}

class TstdlBridgeService {
    constructor() {
        this.#injector = inject(Injector);
        this.#tstdlInjector = new Injector$1('TstdlBridgeServiceInjector');
        this.initialized = false;
    }
    #injector;
    #tstdlInjector;
    initialize() {
        if (this.initialized) {
            return;
        }
        this.initialized = true;
        configureTstdl({ production: !isDevMode() });
        this.configureSignals();
        if (!this.#tstdlInjector.hasRegistration(HttpClientAdapter)) {
            configureAngularHttpClientAdapter();
        }
        this.#tstdlInjector.register(Injector, { useValue: this.#injector });
        this.#tstdlInjector.register(DOCUMENT, { useFactory: () => this.#injector.get(DOCUMENT$1) });
        WrappedR3InjectorRecordsMap.wrap(this.#tstdlInjector, this.#injector);
        this.wrapInjector(this.#injector);
    }
    wrapInjector(injector) {
        const tstdlInjector = this.#tstdlInjector;
        const originalGet = injector.constructor.prototype.get;
        function tstdlGetWrapper(...args) {
            if (isInInjectionContext()) {
                return originalGet.apply(this, args);
            }
            return runInInjectionContext$1(tstdlInjector, () => originalGet.apply(this, args));
        }
        injector.constructor.prototype.get = tstdlGetWrapper;
    }
    configureSignals() {
        configureSignals({
            signal,
            computed,
            effect: (effectFn, options) => {
                try {
                    assertInInjectionContext(TstdlBridgeService);
                    return effect(effectFn, options);
                }
                catch {
                    return effect(effectFn, { injector: this.#injector, ...options });
                }
            },
            untracked,
            isSignal,
            toSignal: (source, options) => {
                try {
                    assertInInjectionContext(TstdlBridgeService);
                    return toSignal(source, options);
                }
                catch {
                    return toSignal(source, { injector: this.#injector, ...options });
                }
            },
            toObservable: (source, options) => {
                try {
                    assertInInjectionContext(TstdlBridgeService);
                    return toObservable(source, options);
                }
                catch {
                    return toObservable(source, { injector: this.#injector, ...options });
                }
            },
            isInSignalsInjectionContext: () => isInInjectionContext(),
            getCurrentSignalsInjector: () => inject(Injector),
            runInSignalsInjectionContext: (injector, fn) => runInInjectionContext(injector, fn)
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: TstdlBridgeService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: TstdlBridgeService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: TstdlBridgeService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

const pipes = [
    DateTimeLocalePipe,
    DateTimePipe,
    DateTimeToDatePipe,
    DecyclePipe,
    DurationPipe,
    DynamicTextPipe,
    LocalizeEnumPipe,
    LocalizePipe,
    NumberLocalePipe,
    NumericDateToDateTimePipe,
    NumericTimeToDateTimePipe,
    OptionalLocalizePipe,
    PadPipe,
    SafeHtmlPipe,
    SafeResourceUrlPipe,
    SafeUrlPipe,
    SerializePipe
];
const directives = [
    AutoForDirective,
    AutoIdDirective,
    InputPatternDirective,
    LazyDirective,
    LazyListDirective,
    LetDirective,
    RepeatDirective,
    VisibilityObserverDirective
];
const components = [
    TstdlSkeletonComponent,
    TstdlIndeterminateProgressBarComponent,
    TstdlColoredProgressbarComponent
];
const declarations = [
    ...pipes,
    ...directives,
    ...components
];
class TstdlAngularModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: TstdlAngularModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.9", ngImport: i0, type: TstdlAngularModule, imports: [DateTimeLocalePipe,
            DateTimePipe,
            DateTimeToDatePipe,
            DecyclePipe,
            DurationPipe,
            DynamicTextPipe,
            LocalizeEnumPipe,
            LocalizePipe,
            NumberLocalePipe,
            NumericDateToDateTimePipe,
            NumericTimeToDateTimePipe,
            OptionalLocalizePipe,
            PadPipe,
            SafeHtmlPipe,
            SafeResourceUrlPipe,
            SafeUrlPipe,
            SerializePipe, AutoForDirective,
            AutoIdDirective,
            InputPatternDirective,
            LazyDirective,
            LazyListDirective,
            LetDirective,
            RepeatDirective,
            VisibilityObserverDirective, TstdlSkeletonComponent,
            TstdlIndeterminateProgressBarComponent,
            TstdlColoredProgressbarComponent], exports: [DateTimeLocalePipe,
            DateTimePipe,
            DateTimeToDatePipe,
            DecyclePipe,
            DurationPipe,
            DynamicTextPipe,
            LocalizeEnumPipe,
            LocalizePipe,
            NumberLocalePipe,
            NumericDateToDateTimePipe,
            NumericTimeToDateTimePipe,
            OptionalLocalizePipe,
            PadPipe,
            SafeHtmlPipe,
            SafeResourceUrlPipe,
            SafeUrlPipe,
            SerializePipe, AutoForDirective,
            AutoIdDirective,
            InputPatternDirective,
            LazyDirective,
            LazyListDirective,
            LetDirective,
            RepeatDirective,
            VisibilityObserverDirective, TstdlSkeletonComponent,
            TstdlIndeterminateProgressBarComponent,
            TstdlColoredProgressbarComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: TstdlAngularModule, providers: [
            provideAppInitializer(appInitializer)
        ], imports: [TstdlIndeterminateProgressBarComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: TstdlAngularModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: declarations,
                    exports: declarations,
                    providers: [
                        provideAppInitializer(appInitializer)
                    ]
                }]
        }] });
function appInitializer() {
    const bridgeService = inject(TstdlBridgeService);
    bridgeService.initialize();
}
function provideTstdlAngular() {
    return importProvidersFrom(TstdlAngularModule);
}

/**
 * Generated bundle index. Do not edit.
 */

export { AngularHttpClientAdapter, AppStabilizationService, ApplicationTickService, AutoForDirective, AutoIdDirective, DateInputControlValueAccessor, DateTimeLocalePipe, DateTimePipe, DateTimeToDatePipe, DecyclePipe, DragDirective, DropDirective, DurationPipe, DynamicTextPipe, ErrorHandlerMessageService, ErrorHandlerService, ErrorHandlerServiceOptions, FilterHelperDirective, InputPatternDirective, LazyDirective, LazyListDirective, LetDirective, LifecycleUtils, LocalizeEnumPipe, LocalizePipe, NotificationService, NumberLocalePipe, NumericDateToDateTimePipe, NumericTimeToDateTimePipe, OptionalLocalizePipe, PadPipe, RepeatDirective, RoutingService, SafeHtmlPipe, SafeResourceUrlPipe, SafeUrlPipe, SanitizePipe, SerializePipe, ToObservablePipe, TstdlAngularModule, TstdlBridgeService, TstdlColoredProgressbarComponent, TstdlIndeterminateProgressBarComponent, TstdlMarkdownComponent, TstdlSkeletonComponent, VisibilityObserverDirective, booleanTransform, booleanTransformWithFallback, collapseAnimation, configureAngularHttpClientAdapter, fadeInOutAnimation, getAnimateTimings, heightAnimation, injectFragmet, injectFragmet$, injectParameter, injectParameter$, injectParameters, injectParameters$, injectQueryParameter, injectQueryParameter$, injectQueryParameters, injectQueryParameters$, injectRouteData, injectRouteData$, injectRoutingService, isMessageBoxSelectInput, isMessageBoxTextAreaInput, isMessageBoxTextInput, messageBoxSelectInput, messageBoxTextAreaInput, messageBoxTextInput, numberTransform, numberTransformWithFallback, provideTstdlAngular, errorHandledResource as resource, routeData, runGuardedInZone, runInZone, runOutsideAngular, runTaskInZone, slideInOutAnimation, waitForAppStabilization, widthAnimation };
//# sourceMappingURL=tstdl-angular.mjs.map
