import type { Signal, WritableSignal } from '@angular/core';
import type { NavigationExtras } from '@angular/router';
import { ActivatedRoute, Router } from '@angular/router';
import type { Record, SimplifiedLiteralUnion, TypedOmit } from '@tstdl/base/types';
import type { Observable } from 'rxjs';
export type TransformOptions<T extends string | string[] | null, TTransform> = {
    transform?: ((value: T) => TTransform) | {
        fromString: (value: T) => TTransform;
        toString?: (value: TTransform) => T;
    };
};
type WithTransformOptions<T extends string | string[] | null, TTransform> = Required<TransformOptions<T, TTransform>>;
type WithoutTransformOptions = TypedOmit<TransformOptions<string, undefined>, 'transform'> & {
    transform?: undefined;
};
export type InjectParameterOptions = {
    optional?: boolean;
};
export declare class RoutingService {
    readonly router: Router;
    readonly route: ActivatedRoute;
    setQueryParameter(key: string, value: string | string[] | null): Promise<void>;
    setQueryParameters(parameters: Record<string, string | string[] | null>, options?: Pick<NavigationExtras, 'queryParamsHandling'>): Promise<void>;
    setFragment(value: string | null): Promise<void>;
}
export declare function injectRoutingService(): RoutingService;
export declare function injectParameter<T extends string>(parameter: string, options: InjectParameterOptions & {
    optional: true;
}): Signal<SimplifiedLiteralUnion<T> | null>;
export declare function injectParameter<T extends string>(parameter: string, options?: InjectParameterOptions & {
    optional?: false;
}): Signal<SimplifiedLiteralUnion<T>>;
export declare function injectParameter$<T extends string>(parameter: string, options: InjectParameterOptions & {
    optional: true;
}): Observable<SimplifiedLiteralUnion<T> | null>;
export declare function injectParameter$<T extends string>(parameter: string, options?: InjectParameterOptions & {
    optional?: false;
}): Observable<SimplifiedLiteralUnion<T>>;
export declare function injectParameter$<T extends string>(parameter: string, options?: InjectParameterOptions): Observable<SimplifiedLiteralUnion<T> | null>;
export declare function injectParameters<T extends string>(parameter: string): Signal<SimplifiedLiteralUnion<T>[]>;
export declare function injectParameters$<T extends string>(parameter: string): Observable<SimplifiedLiteralUnion<T>[]>;
export declare function injectQueryParameter<T extends string, TTransform>(parameter: string, options: WithTransformOptions<SimplifiedLiteralUnion<T> | null, TTransform>): WritableSignal<TTransform>;
export declare function injectQueryParameter<T extends string>(parameter: string, options?: WithoutTransformOptions): WritableSignal<SimplifiedLiteralUnion<T> | null>;
export declare function injectQueryParameter$<T extends string>(parameter: string): Observable<SimplifiedLiteralUnion<T> | null>;
export declare function injectQueryParameters<T extends string, TTransform>(parameter: string, options: WithTransformOptions<SimplifiedLiteralUnion<T>[], TTransform>): WritableSignal<TTransform>;
export declare function injectQueryParameters<T extends string>(parameter: string, options?: WithoutTransformOptions): WritableSignal<SimplifiedLiteralUnion<T>[]>;
export declare function injectQueryParameters$<T extends string>(parameter: string): Observable<SimplifiedLiteralUnion<T>[]>;
export declare function injectFragmet(): WritableSignal<string | null>;
export declare function injectFragmet$(): Observable<string | null>;
export declare function injectRouteData<T extends Record = Record>(): Signal<T>;
export declare function injectRouteData$<T extends Record = Record>(): Observable<T>;
export {};
