import type { AfterContentChecked, AfterContentInit, AfterViewChecked, AfterViewInit, OnChanges, OnDestroy, OnInit, SimpleChange, SimpleChanges } from '@angular/core';
import type { CancellationSignal } from '@tstdl/base/cancellation';
import type { TypedOmit } from '@tstdl/base/types';
import type { Observable } from 'rxjs';
import * as i0 from "@angular/core";
export type TypedSimpleChange<T> = TypedOmit<SimpleChange, 'previousValue' | 'currentValue'> & {
    previousValue: T;
    currentValue: T;
};
type ParentProperties<Parent> = Exclude<keyof Parent, keyof LifecycleUtils>;
export declare class LifecycleUtils<Parent = any> implements OnInit, OnChanges, OnDestroy, AfterViewInit, AfterContentInit, AfterViewChecked, AfterContentChecked {
    #private;
    private readonly initSubject;
    private readonly destroySubject;
    private readonly changesSubject;
    private readonly viewInitSubject;
    private readonly contentInitSubject;
    private readonly viewCheckedSubject;
    private readonly contentCheckedSubject;
    private readonly ionViewWillEnterSubject;
    private readonly ionViewDidEnterSubject;
    private readonly ionViewWillLeaveSubject;
    private readonly ionViewDidLeaveSubject;
    /**
     * emits on `ngOnInit`. Also emits if subscribed afterwards
     * @see {@link OnInit}
     */
    readonly init$: Observable<void>;
    /**
     * emits on `ngOnChanges`
     * @see {@link OnChanges}
     */
    readonly changes$: Observable<SimpleChanges>;
    /**
     * emits on `ngOnDestroy`. Also emits if subscribed afterwards
     * @see {@link OnDestroy}
     */
    readonly destroy$: Observable<void>;
    /**
     * emits on `ngAfterViewInit`. Also emits if subscribed afterwards
     * @see {@link AfterViewInit}
     */
    readonly viewInit$: Observable<void>;
    /**
     * emits on `ngAfterContentInit`. Also emits if subscribed afterwards
     * @see {@link AfterContentInit}
     */
    readonly contentInit$: Observable<void>;
    /**
     * emits on `ngAfterViewChecked`
     * @see {@link AfterViewChecked}
     */
    readonly viewChecked$: Observable<void>;
    /**
     * emits on `ngAfterContentChecked`
     * @see {@link AfterContentChecked}
     */
    readonly contentChecked$: Observable<void>;
    /**
     * emits on `ionViewWillEnter`
     */
    readonly ionViewWillEnter$: Observable<void>;
    /**
     * emits on `ionViewDidEnter`
     */
    readonly ionViewDidEnter$: Observable<void>;
    /**
     * emits on `ionViewWillLeave`
     */
    readonly ionViewWillLeave$: Observable<void>;
    /**
     * emits on `ionViewDidLeave`
     */
    readonly ionViewDidLeave$: Observable<void>;
    /**
     * {@link CancellationToken} bound to {@link destroy$}
     */
    get destroySignal(): CancellationSignal;
    constructor();
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    ngAfterViewInit(): void;
    ngAfterContentInit(): void;
    ngAfterViewChecked(): void;
    ngAfterContentChecked(): void;
    ionViewWillEnter(): void;
    ionViewDidEnter(): void;
    ionViewWillLeave(): void;
    ionViewDidLeave(): void;
    observeChanges<Property extends ParentProperties<Parent>>(property: Property): Observable<TypedSimpleChange<Parent[Property]>>;
    observe<Property extends ParentProperties<Parent>>(property: Property): Observable<Parent[Property]>;
    static ɵfac: i0.ɵɵFactoryDeclaration<LifecycleUtils<any>, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<LifecycleUtils<any>>;
}
export {};
