import * as i1 from '@angular/common';
import { NgClass } from '@angular/common';
import * as i0 from '@angular/core';
import { inject, ChangeDetectorRef, input, booleanAttribute, computed, effect, ViewEncapsulation, ChangeDetectionStrategy, Component } from '@angular/core';
import { MatRipple } from '@angular/material/core';
import { resolveValueOrProvider } from '@tstdl/base/utils';
import { objectEntries, fromEntries } from '@tstdl/base/utils/object';

class TstdlButtonConfig {
}
function provideTstdlButtonConfig(config) {
    return { provide: TstdlButtonConfig, useValue: config };
}

class ButtonComponent {
    #ngClass;
    #ripple;
    #config;
    constructor() {
        this.#ngClass = inject(NgClass);
        this.#ripple = inject(MatRipple);
        this.#config = inject(TstdlButtonConfig, { optional: true });
        this.changeDetector = inject(ChangeDetectorRef);
        this.design = input(null);
        this.color = input(null);
        this.size = input(null);
        this.coloredText = input(null, { transform: booleanAttribute });
        this.invertIconPadding = input(false, { transform: booleanAttribute });
        this.disabled = input(false, { transform: booleanAttribute });
        this.inert = input(false, { transform: booleanAttribute });
        this.disabledAttribute = computed(() => this.disabled() ? true : null);
        this.classes = computed(() => {
            const design = this.design() ?? resolveValueOrProvider(this.#config?.default?.design) ?? 'flat';
            const size = this.size() ?? resolveValueOrProvider(this.#config?.default?.size) ?? 'normal';
            const color = this.color() ?? resolveValueOrProvider(this.#config?.default?.color) ?? 'accent';
            const coloredText = this.coloredText() ?? resolveValueOrProvider(this.#config?.default?.coloredText) ?? false;
            const invertIconPadding = this.invertIconPadding();
            const disabled = this.disabled();
            const small = size == 'small';
            const useNoneStyle = design == 'none';
            const useFlatStyle = design == 'flat';
            const useOutlineStyle = (design == 'outline') || (design == 'icon-outline');
            const useIconStyle = (design == 'icon') || (design == 'icon-outline');
            const ngClassEntries = objectEntries({
                [`tsl-button-${color}`]: true,
                'tsl-button-flat': useFlatStyle,
                'tsl-button-outline': useOutlineStyle,
                'tsl-button-icon': useIconStyle,
                'tsl-button-none': useNoneStyle,
                'tsl-button-small': small,
                'tsl-button-colored-text': coloredText,
                'tsl-button-icon-invert-padding': invertIconPadding
            });
            return fromEntries(ngClassEntries
                .filter(([, classesEnabled]) => classesEnabled)
                .map(([key, value]) => [disabled ? key.split(' ').filter((k) => !k.includes('hover:')).join(' ') : key, value]));
        });
        effect(() => {
            this.#ngClass.ngClass = this.classes();
            this.changeDetector.markForCheck();
        });
        effect(() => (this.#ripple.disabled = this.disabled()));
    }
    ngOnInit() {
        this.#ripple.ngOnInit();
    }
    ngOnDestroy() {
        this.#ripple.ngOnDestroy();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: ButtonComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.1.0", version: "19.2.9", type: ButtonComponent, isStandalone: true, selector: "[tslButton]", inputs: { design: { classPropertyName: "design", publicName: "design", isSignal: true, isRequired: false, transformFunction: null }, color: { classPropertyName: "color", publicName: "color", isSignal: true, isRequired: false, transformFunction: null }, size: { classPropertyName: "size", publicName: "size", isSignal: true, isRequired: false, transformFunction: null }, coloredText: { classPropertyName: "coloredText", publicName: "coloredText", isSignal: true, isRequired: false, transformFunction: null }, invertIconPadding: { classPropertyName: "invertIconPadding", publicName: "invertIconPadding", isSignal: true, isRequired: false, transformFunction: null }, disabled: { classPropertyName: "disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null }, inert: { classPropertyName: "inert", publicName: "inert", isSignal: true, isRequired: false, transformFunction: null } }, host: { properties: { "attr.disabled": "disabledAttribute()" } }, providers: [MatRipple], hostDirectives: [{ directive: i1.NgClass }], ngImport: i0, template: "<ng-content></ng-content>\n", styles: ["@layer tstdl.components{[tslButton]{position:relative;display:inline;overflow:hidden;border-radius:.5rem;font-size:1rem;line-height:1.5rem;font-weight:600;outline:2px solid transparent;outline-offset:2px;transition-property:background,border,opacity,box-shadow,color;transition-timing-function:cubic-bezier(.4,0,.2,1);transition-duration:.15s}[tslButton]:disabled{cursor:not-allowed;opacity:.65}[tslButton]:not(.tsl-button-icon):not(.tsl-button-none){padding:.375rem 1rem}[tslButton]:not(.tsl-button-icon):not(.tsl-button-none).tsl-button-small{padding:.25rem .5rem;font-size:.875rem;line-height:1.25rem}[tslButton].tsl-button-outline{background-color:rgb(var(--tsl-color-neutral-400) / .1);--tw-ring-inset: inset }[tslButton].tsl-button-icon{aspect-ratio:1 / 1;border-radius:9999px;padding:.625rem}[tslButton].tsl-button-icon:hover{background-color:rgb(var(--tsl-color-neutral-800) / .1)}[tslButton].tsl-button-icon:hover:is(.tsl-dark *){background-color:rgb(var(--tsl-color-neutral-200) / .1)}[tslButton].tsl-button-icon.tsl-button-icon-invert-padding{margin:-.625rem}[tslButton].tsl-button-icon.tsl-button-small{padding:.375rem}[tslButton].tsl-button-icon.tsl-button-small.tsl-button-icon-invert-padding{margin:-.375rem}[tslButton].tsl-button-white.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(255 255 255 / var(--tw-bg-opacity, 1));--tw-text-opacity: 1;color:rgb(var(--tsl-color-neutral-800) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-white.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-neutral-200) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-white.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-neutral-200) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-white.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(255 255 255 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-white.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-neutral-200) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-white.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-white.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-neutral-200) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-white.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(var(--tsl-color-neutral-800) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-white.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(var(--tsl-color-neutral-700) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-white.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(255 255 255 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-white.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(var(--tsl-color-neutral-700) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-transparent.tsl-button-flat{background-color:transparent}[tslButton].tsl-button-transparent.tsl-button-flat:hover{background-color:rgb(var(--tsl-color-neutral-500) / .1)}[tslButton].tsl-button-transparent.tsl-button-flat:hover:is(.tsl-dark *){background-color:rgb(var(--tsl-color-neutral-200) / .15)}[tslButton].tsl-button-transparent.tsl-button-outline:hover{background-color:rgb(var(--tsl-color-neutral-500) / .1)}[tslButton].tsl-button-transparent.tsl-button-outline:hover:is(.tsl-dark *){background-color:rgb(var(--tsl-color-neutral-200) / .15)}[tslButton].tsl-button-accent.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-accent-400) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-accent-500) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-accent-600) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-accent-500) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(var(--tsl-color-accent-900) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(var(--tsl-color-accent-100) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(var(--tsl-color-accent-400) / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-accent.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-accent-400) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-accent.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-accent-600) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(var(--tsl-color-accent-600) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(var(--tsl-color-accent-900) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(var(--tsl-color-accent-600) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(var(--tsl-color-accent-100) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-neutral-300) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-neutral-400) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-neutral-600) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-neutral-500) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(var(--tsl-color-neutral-800) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(var(--tsl-color-neutral-200) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(var(--tsl-color-neutral-400) / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-neutral.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-neutral-400) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-neutral.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-neutral-600) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-outline.tsl-button-colored-text,[tslButton].tsl-button-neutral.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(var(--tsl-color-neutral-800) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(var(--tsl-color-neutral-200) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(var(--tsl-color-neutral-200) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(214 211 209 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(168 162 158 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(87 83 78 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(120 113 108 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(41 37 36 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(231 229 228 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(168 162 158 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-stone.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(168 162 158 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-stone.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(87 83 78 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-outline.tsl-button-colored-text,[tslButton].tsl-button-stone.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(41 37 36 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(231 229 228 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(231 229 228 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-red.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(248 113 113 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-red.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(239 68 68 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-red.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(220 38 38 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-red.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(239 68 68 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-red.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(127 29 29 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-red.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(254 226 226 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-red.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(248 113 113 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-red.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(248 113 113 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-red.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-red.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(220 38 38 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-red.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(220 38 38 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-red.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(127 29 29 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-red.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(220 38 38 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-red.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(254 226 226 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(251 146 60 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(249 115 22 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(234 88 12 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(249 115 22 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(124 45 18 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(255 237 213 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(251 146 60 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-orange.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(251 146 60 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-orange.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(234 88 12 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(234 88 12 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(124 45 18 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(234 88 12 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(255 237 213 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(251 191 36 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(245 158 11 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(217 119 6 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(245 158 11 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(120 53 15 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(254 243 199 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(251 191 36 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-amber.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(251 191 36 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-amber.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(217 119 6 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(217 119 6 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(120 53 15 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(217 119 6 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(254 243 199 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(250 204 21 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(234 179 8 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(202 138 4 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(234 179 8 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(113 63 18 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(254 249 195 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(250 204 21 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-yellow.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(250 204 21 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-yellow.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(202 138 4 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(202 138 4 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(113 63 18 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(202 138 4 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(254 249 195 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(163 230 53 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(132 204 22 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(101 163 13 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(132 204 22 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(54 83 20 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(236 252 203 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(163 230 53 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-lime.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(163 230 53 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-lime.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(101 163 13 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(101 163 13 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(54 83 20 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(101 163 13 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(236 252 203 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-green.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(74 222 128 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-green.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(34 197 94 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-green.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(22 163 74 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-green.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(34 197 94 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-green.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(20 83 45 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-green.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(220 252 231 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-green.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(74 222 128 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-green.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(74 222 128 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-green.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-green.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(22 163 74 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-green.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(22 163 74 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-green.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(20 83 45 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-green.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(22 163 74 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-green.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(220 252 231 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(52 211 153 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(16 185 129 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(5 150 105 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(16 185 129 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(6 78 59 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(209 250 229 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(52 211 153 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-emerald.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(52 211 153 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-emerald.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(5 150 105 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(5 150 105 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(6 78 59 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(5 150 105 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(209 250 229 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(45 212 191 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(20 184 166 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(13 148 136 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(20 184 166 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(19 78 74 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(204 251 241 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(45 212 191 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-teal.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(45 212 191 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-teal.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(13 148 136 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(13 148 136 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(19 78 74 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(13 148 136 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(204 251 241 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(34 211 238 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(6 182 212 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(8 145 178 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(6 182 212 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(22 78 99 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(207 250 254 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(34 211 238 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-cyan.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(34 211 238 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-cyan.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(8 145 178 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(8 145 178 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(22 78 99 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(8 145 178 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(207 250 254 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(56 189 248 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(14 165 233 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(2 132 199 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(14 165 233 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(12 74 110 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(224 242 254 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(56 189 248 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-sky.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(56 189 248 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-sky.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(2 132 199 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(2 132 199 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(12 74 110 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(2 132 199 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(224 242 254 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(96 165 250 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(59 130 246 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(37 99 235 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(59 130 246 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(30 58 138 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(219 234 254 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(96 165 250 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-blue.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(96 165 250 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-blue.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(37 99 235 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(37 99 235 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(30 58 138 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(37 99 235 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(219 234 254 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(129 140 248 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(99 102 241 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(79 70 229 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(99 102 241 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(49 46 129 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(224 231 255 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(129 140 248 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-indigo.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(129 140 248 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-indigo.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(79 70 229 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(79 70 229 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(49 46 129 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(79 70 229 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(224 231 255 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(167 139 250 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(139 92 246 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(124 58 237 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(139 92 246 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(76 29 149 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(237 233 254 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(167 139 250 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-violet.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(167 139 250 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-violet.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(124 58 237 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(124 58 237 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(76 29 149 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(124 58 237 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(237 233 254 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(192 132 252 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(168 85 247 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(147 51 234 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(168 85 247 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(88 28 135 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(243 232 255 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(192 132 252 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-purple.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(192 132 252 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-purple.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(147 51 234 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(147 51 234 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(88 28 135 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(147 51 234 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(243 232 255 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(232 121 249 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(217 70 239 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(192 38 211 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(217 70 239 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(112 26 117 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(250 232 255 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(232 121 249 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-fuchsia.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(232 121 249 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-fuchsia.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(192 38 211 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(192 38 211 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(112 26 117 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(192 38 211 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(250 232 255 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(244 114 182 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(236 72 153 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(219 39 119 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(236 72 153 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(131 24 67 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(252 231 243 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(244 114 182 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-pink.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(244 114 182 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-pink.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(219 39 119 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(219 39 119 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(131 24 67 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(219 39 119 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(252 231 243 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(251 113 133 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(244 63 94 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(225 29 72 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(244 63 94 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(136 19 55 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(255 228 230 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(251 113 133 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-rose.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(251 113 133 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-rose.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(225 29 72 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(225 29 72 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(136 19 55 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(225 29 72 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(255 228 230 / var(--tw-text-opacity, 1))}}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.9", ngImport: i0, type: ButtonComponent, decorators: [{
            type: Component,
            args: [{ selector: '[tslButton]', imports: [], changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, providers: [MatRipple], hostDirectives: [NgClass], host: {
                        '[attr.disabled]': 'disabledAttribute()'
                    }, template: "<ng-content></ng-content>\n", styles: ["@layer tstdl.components{[tslButton]{position:relative;display:inline;overflow:hidden;border-radius:.5rem;font-size:1rem;line-height:1.5rem;font-weight:600;outline:2px solid transparent;outline-offset:2px;transition-property:background,border,opacity,box-shadow,color;transition-timing-function:cubic-bezier(.4,0,.2,1);transition-duration:.15s}[tslButton]:disabled{cursor:not-allowed;opacity:.65}[tslButton]:not(.tsl-button-icon):not(.tsl-button-none){padding:.375rem 1rem}[tslButton]:not(.tsl-button-icon):not(.tsl-button-none).tsl-button-small{padding:.25rem .5rem;font-size:.875rem;line-height:1.25rem}[tslButton].tsl-button-outline{background-color:rgb(var(--tsl-color-neutral-400) / .1);--tw-ring-inset: inset }[tslButton].tsl-button-icon{aspect-ratio:1 / 1;border-radius:9999px;padding:.625rem}[tslButton].tsl-button-icon:hover{background-color:rgb(var(--tsl-color-neutral-800) / .1)}[tslButton].tsl-button-icon:hover:is(.tsl-dark *){background-color:rgb(var(--tsl-color-neutral-200) / .1)}[tslButton].tsl-button-icon.tsl-button-icon-invert-padding{margin:-.625rem}[tslButton].tsl-button-icon.tsl-button-small{padding:.375rem}[tslButton].tsl-button-icon.tsl-button-small.tsl-button-icon-invert-padding{margin:-.375rem}[tslButton].tsl-button-white.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(255 255 255 / var(--tw-bg-opacity, 1));--tw-text-opacity: 1;color:rgb(var(--tsl-color-neutral-800) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-white.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-neutral-200) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-white.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-neutral-200) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-white.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(255 255 255 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-white.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-neutral-200) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-white.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-white.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-neutral-200) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-white.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(var(--tsl-color-neutral-800) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-white.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(var(--tsl-color-neutral-700) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-white.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(255 255 255 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-white.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(var(--tsl-color-neutral-700) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-transparent.tsl-button-flat{background-color:transparent}[tslButton].tsl-button-transparent.tsl-button-flat:hover{background-color:rgb(var(--tsl-color-neutral-500) / .1)}[tslButton].tsl-button-transparent.tsl-button-flat:hover:is(.tsl-dark *){background-color:rgb(var(--tsl-color-neutral-200) / .15)}[tslButton].tsl-button-transparent.tsl-button-outline:hover{background-color:rgb(var(--tsl-color-neutral-500) / .1)}[tslButton].tsl-button-transparent.tsl-button-outline:hover:is(.tsl-dark *){background-color:rgb(var(--tsl-color-neutral-200) / .15)}[tslButton].tsl-button-accent.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-accent-400) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-accent-500) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-accent-600) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-accent-500) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(var(--tsl-color-accent-900) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(var(--tsl-color-accent-100) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(var(--tsl-color-accent-400) / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-accent.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-accent-400) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-accent.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-accent-600) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(var(--tsl-color-accent-600) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(var(--tsl-color-accent-900) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(var(--tsl-color-accent-600) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-accent.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(var(--tsl-color-accent-100) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-neutral-300) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-neutral-400) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-neutral-600) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-neutral-500) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(var(--tsl-color-neutral-800) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(var(--tsl-color-neutral-200) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(var(--tsl-color-neutral-400) / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-neutral.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-neutral-400) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-neutral.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(var(--tsl-color-neutral-600) / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-outline.tsl-button-colored-text,[tslButton].tsl-button-neutral.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(var(--tsl-color-neutral-800) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(var(--tsl-color-neutral-200) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-neutral.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(var(--tsl-color-neutral-200) / var(--tw-text-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(214 211 209 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(168 162 158 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(87 83 78 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(120 113 108 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(41 37 36 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(231 229 228 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(168 162 158 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-stone.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(168 162 158 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-stone.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(87 83 78 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-outline.tsl-button-colored-text,[tslButton].tsl-button-stone.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(41 37 36 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(231 229 228 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-stone.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(231 229 228 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-red.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(248 113 113 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-red.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(239 68 68 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-red.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(220 38 38 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-red.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(239 68 68 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-red.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(127 29 29 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-red.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(254 226 226 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-red.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(248 113 113 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-red.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(248 113 113 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-red.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-red.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(220 38 38 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-red.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(220 38 38 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-red.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(127 29 29 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-red.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(220 38 38 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-red.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(254 226 226 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(251 146 60 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(249 115 22 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(234 88 12 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(249 115 22 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(124 45 18 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(255 237 213 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(251 146 60 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-orange.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(251 146 60 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-orange.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(234 88 12 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(234 88 12 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(124 45 18 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(234 88 12 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-orange.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(255 237 213 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(251 191 36 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(245 158 11 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(217 119 6 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(245 158 11 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(120 53 15 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(254 243 199 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(251 191 36 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-amber.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(251 191 36 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-amber.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(217 119 6 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(217 119 6 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(120 53 15 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(217 119 6 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-amber.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(254 243 199 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(250 204 21 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(234 179 8 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(202 138 4 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(234 179 8 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(113 63 18 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(254 249 195 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(250 204 21 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-yellow.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(250 204 21 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-yellow.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(202 138 4 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(202 138 4 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(113 63 18 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(202 138 4 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-yellow.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(254 249 195 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(163 230 53 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(132 204 22 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(101 163 13 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(132 204 22 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(54 83 20 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(236 252 203 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(163 230 53 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-lime.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(163 230 53 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-lime.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(101 163 13 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(101 163 13 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(54 83 20 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(101 163 13 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-lime.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(236 252 203 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-green.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(74 222 128 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-green.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(34 197 94 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-green.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(22 163 74 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-green.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(34 197 94 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-green.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(20 83 45 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-green.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(220 252 231 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-green.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(74 222 128 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-green.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(74 222 128 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-green.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-green.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(22 163 74 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-green.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(22 163 74 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-green.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(20 83 45 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-green.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(22 163 74 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-green.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(220 252 231 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(52 211 153 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(16 185 129 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(5 150 105 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(16 185 129 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(6 78 59 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(209 250 229 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(52 211 153 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-emerald.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(52 211 153 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-emerald.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(5 150 105 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(5 150 105 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(6 78 59 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(5 150 105 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-emerald.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(209 250 229 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(45 212 191 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(20 184 166 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(13 148 136 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(20 184 166 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(19 78 74 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(204 251 241 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(45 212 191 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-teal.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(45 212 191 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-teal.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(13 148 136 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(13 148 136 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(19 78 74 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(13 148 136 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-teal.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(204 251 241 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(34 211 238 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(6 182 212 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(8 145 178 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(6 182 212 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(22 78 99 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(207 250 254 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(34 211 238 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-cyan.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(34 211 238 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-cyan.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(8 145 178 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(8 145 178 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(22 78 99 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(8 145 178 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-cyan.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(207 250 254 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(56 189 248 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(14 165 233 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(2 132 199 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(14 165 233 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(12 74 110 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(224 242 254 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(56 189 248 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-sky.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(56 189 248 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-sky.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(2 132 199 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(2 132 199 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(12 74 110 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(2 132 199 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-sky.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(224 242 254 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(96 165 250 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(59 130 246 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(37 99 235 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(59 130 246 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(30 58 138 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(219 234 254 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(96 165 250 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-blue.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(96 165 250 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-blue.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(37 99 235 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(37 99 235 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(30 58 138 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(37 99 235 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-blue.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(219 234 254 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(129 140 248 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(99 102 241 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(79 70 229 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(99 102 241 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(49 46 129 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(224 231 255 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(129 140 248 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-indigo.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(129 140 248 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-indigo.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(79 70 229 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(79 70 229 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(49 46 129 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(79 70 229 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-indigo.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(224 231 255 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(167 139 250 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(139 92 246 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(124 58 237 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(139 92 246 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(76 29 149 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(237 233 254 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(167 139 250 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-violet.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(167 139 250 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-violet.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(124 58 237 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(124 58 237 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(76 29 149 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(124 58 237 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-violet.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(237 233 254 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(192 132 252 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(168 85 247 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(147 51 234 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(168 85 247 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(88 28 135 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(243 232 255 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(192 132 252 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-purple.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(192 132 252 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-purple.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(147 51 234 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(147 51 234 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(88 28 135 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(147 51 234 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-purple.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(243 232 255 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(232 121 249 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(217 70 239 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(192 38 211 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(217 70 239 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(112 26 117 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(250 232 255 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(232 121 249 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-fuchsia.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(232 121 249 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-fuchsia.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(192 38 211 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(192 38 211 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(112 26 117 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(192 38 211 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-fuchsia.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(250 232 255 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(244 114 182 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(236 72 153 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(219 39 119 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(236 72 153 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(131 24 67 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(252 231 243 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(244 114 182 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-pink.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(244 114 182 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-pink.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(219 39 119 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(219 39 119 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(131 24 67 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(219 39 119 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-pink.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(252 231 243 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-flat{--tw-bg-opacity: 1;background-color:rgb(251 113 133 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-flat:hover{--tw-bg-opacity: 1;background-color:rgb(244 63 94 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-flat:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(225 29 72 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-flat:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(244 63 94 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-flat.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(136 19 55 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-flat.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(255 228 230 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-outline{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000);--tw-ring-opacity: 1;--tw-ring-color: rgb(251 113 133 / var(--tw-ring-opacity, 1)) }[tslButton].tsl-button-rose.tsl-button-outline:hover{--tw-bg-opacity: 1;background-color:rgb(251 113 133 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-outline:focus-visible{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}[tslButton].tsl-button-rose.tsl-button-outline:hover:is(.tsl-dark *){--tw-bg-opacity: 1;background-color:rgb(225 29 72 / var(--tw-bg-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-outline.tsl-button-colored-text{--tw-text-opacity: 1;color:rgb(225 29 72 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-outline.tsl-button-colored-text:hover{--tw-text-opacity: 1;color:rgb(136 19 55 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-outline.tsl-button-colored-text:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(225 29 72 / var(--tw-text-opacity, 1))}[tslButton].tsl-button-rose.tsl-button-outline.tsl-button-colored-text:hover:is(.tsl-dark *){--tw-text-opacity: 1;color:rgb(255 228 230 / var(--tw-text-opacity, 1))}}\n"] }]
        }], ctorParameters: () => [] });

/**
 * Generated bundle index. Do not edit.
 */

export { ButtonComponent, TstdlButtonConfig, provideTstdlButtonConfig };
//# sourceMappingURL=tstdl-angular-button.mjs.map
